@@ -21,8 +21,23 @@
 #ifndef ADDMULT_H
 #define ADDMULT_H
 
+#include <glib.h>
+
+/** possible multi
+ *
+ * name of possible multiplier and
+ * list of belonging aliases */
+typedef struct {
+    char *name;
+    GSList *aliases;
+} possible_mult_t;
+
+
 int addmult(void);
 int addmult2(void);
+char *get_mult(int n);
+int get_mult_count(void);
+unsigned int get_matching_length(char *str, unsigned int n);
 int init_and_load_multipliers(void);
 int remember_multi(char *multiplier, int band, int show_new_band);
 void init_mults();
