@@ -26,11 +26,13 @@
 
 #include <dirent.h>
 #include <errno.h>
+#include <glib.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
 #include "ignore_unused.h"
+#include "keystroke_names.h"
 #include "tlf.h"
 #include "tlf_curses.h"
 #include "ui_utils.h"
@@ -45,8 +47,7 @@ void recordmenue(void) {
     attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
     for (j = 0; j <= 24; j++)
-	mvprintw(j, 0,
-		 "                                                                                ");
+	mvprintw(j, 0, backgrnd_str);
 
     mvprintw(1, 20, "--- TLF SOUND RECORDER UTILITY ---");
     mvprintw(6, 20, "F1 ... F12, S, C: Record Messages");
@@ -77,7 +78,7 @@ void do_record(int message_nr) {
     IGNORE(system(commands));;
     //G4KNO: Loop until <esc> keypress
     while (1) {
-	if (key_get() == 27) {
+	if (key_get() == ESCAPE) {
 	    //kill process (SIGINT=Ctrl-C).
 	    IGNORE(system("pkill -SIGINT -n rec"));;
 	    break;
@@ -214,7 +215,7 @@ void record(void) {
 				i = 10;
 				j++;
 			    }
-			    strncpy(printname, soundfilename->d_name, 6);
+			    g_strlcpy(printname, soundfilename->d_name, 7);
 			    mvprintw(j, i, "%s", printname);
 			    refreshp();
 
@@ -252,7 +253,7 @@ void record(void) {
 		IGNORE(system(commands));;
 		runnit = 0;
 		break;
-	    case 27:
+	    case ESCAPE:
 		runnit = 0;
 	}
     }
