@@ -27,6 +27,7 @@
 
 #include <ctype.h>
 #include <fcntl.h>
+#include <math.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -48,6 +49,7 @@
 #include "gettxinfo.h"
 #include "grabspot.h"
 #include "ignore_unused.h"
+#include "keystroke_names.h"
 #include "lancode.h"
 #include "muf.h"
 #include "netkeyer.h"
@@ -68,20 +70,22 @@
 #include "splitscreen.h"
 #include "stoptx.h"
 #include "time_update.h"
+#include "trx_memory.h"
 #include "ui_utils.h"
 #include "writeparas.h"
 #include "showzones.h"
 #include "bands.h"
 #include "fldigixmlrpc.h"
 
-#include <math.h>
-
 #define TUNE_UP 6	/* tune up for 6 s (no more than 10) */
 
+typedef enum { STORE_OR_POP, POP, SWAP } memory_op_t;
+
 void send_bandswitch(freq_t freq);
 int autosend(void);
 int plain_number(char *str);
 void handle_bandswitch(int direction);
+void handle_memory_operation(memory_op_t op);
 
 extern int no_arrows;
 extern char hiscall[];
@@ -106,17 +110,14 @@ int callinput(void) {
     extern int early_started;
     extern char hiscall_sent[];
     extern char comment[];
-    extern int cqmode;
+    extern cqmode_t cqmode;
     extern int trxmode;
-    extern char mode[];
     extern char lastcall[];
     extern int cqdelay;
     extern char his_rst[];
-    extern char backgrnd_str[];
     extern int cluster;
     extern int announcefilter;
     extern char ph_message[14][80];
-    extern freq_t mem;
     extern SCREEN *mainscreen;
     extern int simulator;
     extern int simulator_mode;
@@ -159,7 +160,6 @@ int callinput(void) {
     static struct grab_t grab =  { .state = NONE };
 
 
-
     int cury, curx;
     int j, t, x = 0;
     char instring[2] = { '\0', '\0' };
@@ -169,7 +169,7 @@ int callinput(void) {
     attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
     printcall();	/* print call input field */
-    searchlog(hiscall);
+    searchlog();
 
     while (strlen(hiscall) <= 13) {
 
@@ -199,7 +199,7 @@ int callinput(void) {
 	     * from frequency and if so add call to spot list */
 	    if (bmautoadd != 0 && freqstore != 0) {
 		if (strlen(hiscall) >= 3) {
-		    if (fabsf(freq - freqstore) > 500) {
+		    if (fabs(freq - freqstore) > 500) {
 			add_to_spots(hiscall, freqstore);
 			hiscall[0] = '\0';
 			HideSearchPanel();
@@ -220,7 +220,7 @@ int callinput(void) {
 
 		    showinfo(getctydata_pfx(hiscall));
 		    printcall();
-		    searchlog(hiscall);
+		    searchlog();
 		    freqstore = 0;
 		}
 	    }
@@ -235,7 +235,7 @@ int callinput(void) {
 
 	    /* if we have grabbed a call from spot list and tune away
 	     * then forget about it */
-	    if (fabsf(freq - grab.spotfreq) > 500 && grab.state == REACHED) {
+	    if (fabs(freq - grab.spotfreq) > 500 && grab.state == REACHED) {
 		grab.state = NONE;
 		hiscall[0] = '\0';
 		printcall();
@@ -265,7 +265,7 @@ int callinput(void) {
 	    }
 
 	    // Up Arrow or Alt-e, edit last QSO
-	    if (x == KEY_UP || x == 229) {
+	    if (x == KEY_UP || x == ALT_E) {
 		edit_last();
 		break;
 	    }
@@ -279,11 +279,21 @@ int callinput(void) {
 	    }
 	}
 
+	// Shift-F1: switch back (swap) to CQ frequency if it's in memory
+	//           and start a CQ
+	if (x == SHIFT_F(1)) {
+	    if (cqmode == S_P && memory_get_cqmode() == CQ) {
+		handle_memory_operation(SWAP);
+	    }
+
+	    x = KEY_F(1);   // continue as F1
+	}
+
 	switch (x) {
 
 	    // Plus (+)
 	    // - in non-CT mode switch to other mode (CQ <-> S&P)
-	    // - in CT mode send exchange, log QSO, no message sent.
+	    // - in CT mode send TU and log QSO.
 	    case '+': {
 		if (!ctcomp) {
 
@@ -294,36 +304,33 @@ int callinput(void) {
 			cqmode = CQ;
 
 		    /* and show new mode */
-		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-
-		    if (cqmode == CQ) {
-			mvprintw(0, 2, "Log     ");
-			strcpy(mode, "Log     ");
-		    } else {
-			mvprintw(0, 2, "S&P     ");
-			strcpy(mode, "S&P     ");
-		    }
+		    show_header_line();
 
 		} else {
 
 		    if (strlen(hiscall) > 2) {
-			send_standard_message(2);
-
 			if (((cqww == 1) || (wazmult == 1))
 				&& (*comment == '\0'))
 			    strcpy(comment, cqzone);
 
 			if ((itumult == 1) && (*comment == '\0'))
 			    strcpy(comment, ituzone);
-			x = '\\';   // key for logging QSO without message
 
+			if (*comment == '\0') {
+			    x = -1;
+			} else {
+			    /* F4 (TU macro) */
+			    send_standard_message(3);
+
+			    x = '\\';   // key for logging QSO without message
+			}
 		    }
 		}
 		break;
 	    }
 
 	    // Ctrl-Q (^Q), open QTC window for receiving or sending QTCs.
-	    case 17: {
+	    case CTRL_Q: {
 		if (qtcdirection == 1 || qtcdirection == 3) {	// in case of QTC=RECV or QTC=BOTH
 		    qtc_main_panel(RECV);
 		}
@@ -335,7 +342,7 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-S (^S), open QTC window for sending QTCs.
-	    case 19: {
+	    case CTRL_S: {
 		if (qtcdirection == 2 || qtcdirection == 3) {	// in case of QTC=SEND ot QTC=BOTH
 		    qtc_main_panel(SEND);
 		}
@@ -370,7 +377,7 @@ int callinput(void) {
 	    }
 
 	    // Alt-w (M-w), set Morse weight.
-	    case 247: {
+	    case ALT_W: {
 		char weightbuf[5] = "";
 		char *end;
 
@@ -408,9 +415,9 @@ int callinput(void) {
 	    }
 
 	    // Alt-v (M-v), change Morse speed in CW mode, else band down.
-	    case 246: {
+	    case ALT_V: {
 		if (ctcomp == 1) {
-		    while (x != 27) {	//escape
+		    while (x != ESCAPE) {
 			nicebox(1, 1, 2, 12, "Cw");
 			attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 			mvprintw(2, 2, "Speed:   %2u ", GetCWSpeed());
@@ -431,7 +438,7 @@ int callinput(void) {
 			    mvprintw(0, 14, "%2u", GetCWSpeed());
 
 			} else
-			    x = 27;	// <Escape>
+			    x = ESCAPE;
 
 			clear_display();
 		    }
@@ -493,10 +500,17 @@ int callinput(void) {
 	    case '\n':
 	    case KEY_ENTER: {
 		if (strlen(hiscall) > 2 && ctcomp == 1) {
-		    /* there seems to be a call
-		     * means: log it (in CT mode */
-		    x = 92;	// '\' log without sending message
-		    break;
+		    /* There seems to be a call, log it in CT mode but only if
+		     * the exchange field is not empty.
+		     */
+		    if (comment[0] == '\0') {
+			x = -1;
+			break;
+		    } else {
+			/* Log without sending message. */
+			x = BACKSLASH;
+			break;
+		    }
 		}
 
 		if (strlen(hiscall) < 3 || nob4 == 1)
@@ -505,7 +519,7 @@ int callinput(void) {
 		/* check b4 QSO if call is long enough and 'nob4' off */
 		isdupe = 0;	// LZ3NY  auto-b4 patch
 
-		searchlog(hiscall);
+		searchlog();
 
 		if (isdupe != 0) {
 		    // XXX: Before digi_message, SSB mode sent CW here. - W8BSD
@@ -516,11 +530,15 @@ int callinput(void) {
 		break;
 	    }
 
-	    // <Insert>, send exchange in CT mode
+	    /* <Insert>, send exchange in CT mode */
 	    case KEY_IC: {
 		if (ctcomp != 0) {
-		    send_standard_message(1);		// F2
-
+		    /* F3 (RST macro) */
+		    send_standard_message(2);
+		    /* Set to space to move cursor to exchange field
+		     * which will trigger autofill if available.
+		     */
+		    x = ' ';
 		}
 		break;
 	    }
@@ -547,20 +565,17 @@ int callinput(void) {
 
 	    // Hash, save xcvr freq to mem or restore mem to xcvr.
 	    case '#': {
-		if (mem == 0.0) {
-		    mem = freq;
-		    mvprintw(14, 67, " MEM: %7.1f", mem / 1000.);
-		} else {
-		    freq = mem;
-
-		    set_outfreq(mem);
-
-		    mem = 0.0;
-		    mvprintw(14, 67, "             ");
-		}
-		mvprintw(29, 12, " ");
-		mvprintw(29, 12, "");
-		refreshp();
+		handle_memory_operation(STORE_OR_POP);
+		break;
+	    }
+	    // Dollar, pop memory (MEM -> TRX)
+	    case '$': {
+		handle_memory_operation(POP);
+		break;
+	    }
+	    // Percent, swap memory (MEM <-> TRX)
+	    case '%': {
+		handle_memory_operation(SWAP);
 		break;
 	    }
 
@@ -572,7 +587,7 @@ int callinput(void) {
 
 	    // Semicolon or Alt-n (M-n), insert note in log.
 	    case ';':
-	    case 238: {
+	    case ALT_N: {
 		include_note();
 		x = -1;
 		break;
@@ -589,7 +604,7 @@ int callinput(void) {
 	    case KEY_F(1): {
 		if (trxmode == CWMODE || trxmode == DIGIMODE) {
 
-		    if (cqmode == 0) {
+		    if (cqmode == S_P) {
 			sendspcall();
 		    } else {
 			send_standard_message(0);	/* CQ */
@@ -601,7 +616,7 @@ int callinput(void) {
 		    }
 		} else {
 
-		    if (cqmode == 0)
+		    if (cqmode == S_P)
 			play_file(ph_message[5]);	/* S&P */
 		    else
 			play_file(ph_message[0]);
@@ -643,7 +658,7 @@ int callinput(void) {
 
 		    if (atoi(hiscall) < 1800) {	/*  no frequency */
 			showinfo(getctydata_pfx(hiscall));
-			searchlog(hiscall);
+			searchlog();
 			refreshp();
 		    }
 
@@ -654,8 +669,8 @@ int callinput(void) {
 	    }
 
 	    // Alt-r (M-r) or Alt-s (M-s), toggle score window.
-	    case 242:
-	    case 243: {
+	    case ALT_R:
+	    case ALT_S: {
 		if (showscore_flag == 0)
 		    showscore_flag = 1;
 		else {
@@ -666,13 +681,13 @@ int callinput(void) {
 	    }
 
 	    // Alt-k (M-k), synonym for Ctrl-K (^K).
-	    case 235: {
-		x = 11;		// Ctrl-K
+	    case ALT_K: {
+		x = CTRL_K;		// Ctrl-K
 		break;
 	    }
 
 	    // Alt-a (M-a), cycle cluster window.
-	    case 225: {
+	    case ALT_A: {
 		if (cluster == NOCLUSTER) {
 		    cluster = CLUSTER;	// alt-A
 		    announcefilter = FILTER_ALL;
@@ -686,7 +701,7 @@ int callinput(void) {
 	    }
 
 	    // Alt-b (M-b), band-up for TR-Log mode.
-	    case 226: {
+	    case ALT_B: {
 		if (ctcomp == 0) {
 		    handle_bandswitch(BAND_UP);
 		}
@@ -694,7 +709,7 @@ int callinput(void) {
 	    }
 
 	    // Alt-j (M-j), show station frequencies.
-	    case 234: {
+	    case ALT_J: {
 		if (cluster != FREQWINDOW) {
 		    lastwindow = cluster;
 		    cluster = FREQWINDOW;
@@ -705,7 +720,7 @@ int callinput(void) {
 	    }
 
 	    // Alt-h (M-h), show help.
-	    case 232: {
+	    case ALT_H: {
 		show_help();
 		break;
 	    }
@@ -718,7 +733,7 @@ int callinput(void) {
 	    }
 
 	    // Alt-c (M-c), toggle check window.
-	    case 227: {
+	    case ALT_C: {
 		if (searchflg != SEARCHWINDOW)
 		    searchflg = SEARCHWINDOW;
 		else
@@ -727,14 +742,14 @@ int callinput(void) {
 	    }
 
 	    // Alt-m (M-m), show multipliers.
-	    case 237: {
+	    case ALT_M: {
 		show_mults();
 		refreshp();
 		break;
 	    }
 
 	    // Alt-p (M-p), toggle PTT via cwdaemon
-	    case 240: {
+	    case ALT_P: {
 		if (k_ptt == 0) {
 		    k_ptt = 1;
 		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
@@ -743,10 +758,10 @@ int callinput(void) {
 		    refreshp();
 		    netkeyer(K_PTT, "1");	// ptt on
 		    x = key_get();	// any character to stop tuning
-		    if (x == 240)	// Alt-P (M-p)
+		    if (x == ALT_P)	// Alt-P (M-p)
 			netkeyer(K_PTT, "0");	// ptt off
 		    k_ptt = 0;
-		    mvprintw(0, 2, "%s", mode);
+		    show_header_line();
 		    refreshp();
 		} else
 		    netkeyer(K_PTT, "0");	// ptt off in any case.
@@ -755,7 +770,7 @@ int callinput(void) {
 	    }
 
 	    // Alt-t (M-t), tune xcvr via cwdaemon.
-	    case 244: {
+	    case ALT_T: {
 		int count;
 		gchar *buff;
 
@@ -772,21 +787,21 @@ int callinput(void) {
 
 		while (count != 0) {
 		    usleep(250000);
-		    if ((key_poll()) != -1)	// any key pressed ?
+		    if (key_poll() != -1)	// any key pressed ?
 			break;
 		    count--;
 		}
 
 		netkeyer(K_ABORT, "");	// cw abort
 
-		mvprintw(0, 2, "%s", mode);
+		show_header_line();
 		refreshp();
 
 		break;
 	    }
 
 	    // Alt-z (M-z), show zones worked.
-	    case 250: {
+	    case ALT_Z: {
 		if (cqww == 1) {
 		    if (zonedisplay == 0)
 			zonedisplay = 1;
@@ -802,8 +817,8 @@ int callinput(void) {
 	    }
 
 	    // Alt-q (M-q) or Alt-x (M-x), Exit
-	    case 241:
-	    case 248: {
+	    case ALT_Q:
+	    case ALT_X: {
 		mvprintw(13, 29, "You want to leave tlf? (y/n): ");
 		while (x != 'n' && x != 'N') {
 
@@ -818,12 +833,12 @@ int callinput(void) {
 			exit(0);
 		    }
 		}
-		x = 27;		// <Escape>
+		x = ESCAPE;
 		break;
 	    }
 
 	    // <Escape>, clear call input or stop sending.
-	    case 27: {
+	    case ESCAPE: {
 		if (early_started == 0) {
 		    /* if CW not started early drop call and start anew */
 		    cleanup();
@@ -863,7 +878,7 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-L (^L), resets screen.
-	    case 12: {
+	    case CTRL_L: {
 		endwin();
 		set_term(mainscreen);
 		clear_display();
@@ -872,7 +887,7 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-P (^P), show MUF display.
-	    case 16: {
+	    case CTRL_P: {
 		int currentterm = miniterm;
 		miniterm = 0;
 		muf();
@@ -883,7 +898,7 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-A (^A), add a spot and share on LAN.
-	    case 1: {
+	    case CTRL_A: {
 		addspot();
 		HideSearchPanel();
 		showinfo(SHOWINFO_DUMMY);
@@ -894,7 +909,7 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-B (^B), send spot to DX cluster.
-	    case 2: {
+	    case CTRL_B: {
 		announcefilter = 0;
 		cluster = CLUSTER;
 		send_cluster();
@@ -903,20 +918,19 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-F (^F), change frequency dialog.
-	    case 6: {
+	    case CTRL_F: {
 		change_freq();
 
 		break;
 	    }
 
 	    // Ctrl-G (^G), grab next DX spot from bandmap.
-	    case 7: {
+	    case CTRL_G: {
 		freq_t f = grab_next();
 		if (f > 0.0) {
 		    grab.state = IN_PROGRESS;
 		    grab.spotfreq = f;
-		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-		    mvprintw(0, 2, "%s", mode);
+		    show_header_line();
 		    freqstore = 0;
 		}
 
@@ -924,13 +938,12 @@ int callinput(void) {
 	    }
 
 	    // Alt-g (M-g), grab first spot matching call field chars.
-	    case 231: {
+	    case ALT_G: {
 		double f = grabspot();
 		if (f > 0.0) {
 		    grab.state = IN_PROGRESS;
 		    grab.spotfreq = f;
-		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-		    mvprintw(0, 2, "%s", mode);
+		    show_header_line();
 		    freqstore = 0;
 		}
 
@@ -946,7 +959,7 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-R (^R), toogle trx1, trx2 via lp0 pin 14.
-	    case 18: {
+	    case CTRL_R: {
 		if (k_pin14 == 0) {
 		    k_pin14 = 1;
 		    netkeyer(K_SET14, "1");
@@ -958,8 +971,8 @@ int callinput(void) {
 	    }
 
 	    // Ctrl-T (^T) or Alt-i (M-i), show talk messages.
-	    case 20:
-	    case 233: {
+	    case CTRL_T:
+	    case ALT_I: {
 		if (lan_active != 0) {
 
 		    for (t = 0; t <= 5; t++)
@@ -1043,7 +1056,7 @@ int callinput(void) {
 	    if (atoi(hiscall) < 1800) {	/*  no frequency */
 
 		showinfo(getctydata_pfx(hiscall));
-		searchlog(hiscall);
+		searchlog();
 	    }
 
 	    refreshp();
@@ -1063,8 +1076,8 @@ int callinput(void) {
 	    }
 	}
 
-	if ((x == '\n' || x == KEY_ENTER) || x == 32 || x == 9 || x == 11
-		|| x == 44 || x == 92) {
+	if ((x == '\n' || x == KEY_ENTER) || x == SPACE || x == TAB
+		|| x == CTRL_K || x == 44 || x == BACKSLASH) {
 	    break;
 	}
 
@@ -1134,7 +1147,7 @@ int autosend() {
     timeout = (1.2 / GetCWSpeed()) * cw_message_length(hiscall);
 
     x = -1;
-    while ((x != 27) && (x != '\n' && x != KEY_ENTER)) {
+    while ((x != ESCAPE) && (x != '\n' && x != KEY_ENTER)) {
 	x = -1;
 	while ((x == -1) && (g_timer_elapsed(timer, NULL) < timeout)) {
 
@@ -1163,7 +1176,7 @@ int autosend() {
 	}
 
 	// <Escape>
-	if (x == 27) {
+	if (x == ESCAPE) {
 	    stoptx();
 	    *hiscall_sent = '\0';
 	    early_started = 0;
@@ -1330,3 +1343,39 @@ void handle_bandswitch(int direction) {
 
     send_bandswitch(bandinx);
 }
+
+/** handle TRX memory operation and update screen
+ *
+ **/
+void handle_memory_operation(memory_op_t op) {
+    const freq_t newfreq = memory_get_freq();
+
+    switch (op) {
+	case STORE_OR_POP:
+	    memory_store_or_pop();
+	    break;
+	case POP:
+	    memory_pop();
+	    break;
+	case SWAP:
+	    memory_swap();
+	    break;
+    }
+
+    show_header_line();
+    showinfo(getctydata_pfx(hiscall));
+    searchlog();
+    move(12, 29 + strlen(hiscall));
+
+    if (newfreq <= 0) {
+	return;     // freq not changed
+    }
+
+    // wait until change is reported back from the rig (timeout: 1 sec)
+    for (int i = 0; i < 20; i++) {
+	if (fabs(freq - newfreq) < 100) {
+	    break;
+	}
+	usleep(50000);
+    }
+}
