@@ -29,11 +29,10 @@
 
 void change_freq(void) {
 
-    extern float freq;
+    extern freq_t freq;
     extern int trx_control;
 
     int brkflg = 0;
-    int x;
 
     if (trx_control == 0)
 	return;
@@ -45,7 +44,8 @@ void change_freq(void) {
 	freq_display();
 
 	if (get_outfreq() == 0) {
-	    x = key_get();
+	    // last request has been processed, check keys again
+	    int x = key_poll();
 
 	    int deltaf = 0;
 
@@ -87,6 +87,12 @@ void change_freq(void) {
 		    break;
 		}
 
+		// no key
+		case ERR: {
+		    break;
+		}
+
+		// any other key: exit frequency change mode
 		default: {
 		    brkflg = 1;
 		    break;
@@ -95,19 +101,19 @@ void change_freq(void) {
 	    }
 
 	    if (deltaf) {
-		set_outfreq(freq * 1000 + deltaf);
+		set_outfreq(freq + deltaf);
 	    }
 	}
 
-	if (brkflg == 1) {
-	    brkflg = 0;
+	if (brkflg) {
 	    break;
 	}
 
-	freq_display();
 
 	time_update();
 
+	freq_display();
+
 	usleep(100 * 1000);
 
     }
