@@ -39,6 +39,7 @@
 #include "fldigixmlrpc.h"
 #include "gettxinfo.h"
 #include "ignore_unused.h"
+#include "keystroke_names.h"
 #include "lancode.h"
 #include "listmessages.h"
 #include "logview.h"
@@ -81,25 +82,22 @@ int changepars(void) {
     extern char hiscall[];
     extern int rit;
     extern int trx_control;
-    extern int editor;
     extern int packetinterface;
     extern int nopacket;
     extern int cqdelay;
     extern int ctcomp;
     extern char *config_file;
     extern int miniterm;
-    extern int total;
     extern int simulator;
     extern int cwkeyer;
     extern char synclogfile[];
     extern char sc_volume[];
     extern int cwstart;
     extern int digikeyer;
-    extern int cqmode;
+    extern cqmode_t cqmode;
 
     char parameterstring[20] = "";
     char parameters[52][19];
-    char cmdstring[80];
     int i, k, x, nopar = 0;
     int maxpar = 50;
     int volumebuffer;
@@ -211,7 +209,7 @@ int changepars(void) {
 	    break;
 	}
 	case 6: {		/* MESSAGE  */
-	    message_change(i);
+	    message_change();
 	    break;
 	}
 
@@ -352,18 +350,8 @@ int changepars(void) {
 	case 24:		/* SET PARAMETERS */
 	case 29: {		/* CFG PARAMETERS */
 	    clear();
-	    if (editor == EDITOR_JOE) {
-		strcpy(cmdstring, "joe ");
-	    } else if (editor == EDITOR_VI) {
-		strcpy(cmdstring, "vi ");
-	    } else if (editor == EDITOR_MC) {
-		strcpy(cmdstring, "mcedit ");
-	    } else {
-		strcpy(cmdstring, "e3 ");
-	    }
 
-	    strcat(cmdstring, config_file);
-	    IGNORE(system(cmdstring));;
+	    edit(config_file);
 
 	    read_logcfg();
 	    read_rules();	/* also reread rules file */
@@ -572,21 +560,13 @@ int changepars(void) {
 		synclog(synclogfile);
 	    scroll_log();
 	    /** \todo register return value */
-	    total = 0;
-	    readcalls();
-	    if (qtcdirection > 0) {
-		readqtccalls();
-	    }
+	    log_read_n_score();
 	    clear_display();
 	    break;
 	}
 	case 42: {		/* RESCORE */
 	    /** \todo register return value */
-	    total = 0;
-	    readcalls();
-	    if (qtcdirection > 0) {
-		readqtccalls();
-	    }
+	    log_read_n_score();
 	    clear_display();
 	    break;
 	}
@@ -668,13 +648,13 @@ int changepars(void) {
 	    /* wait for correct input or ESC */
 	    while ((x != 0) && !((x >= 2) && (x <= 5)) && !(x == 'm' - '0')) {
 		x = key_get();
-		if (x == 27)
+		if (x == ESCAPE)
 		    break;
 		x = x - '0';
 	    }
 
 	    /* remember new setting */
-	    if (x != 27) {
+	    if (x != ESCAPE) {
 		if (x == 0 || (x >= 2 && x <= 5))
 		    cwstart = x;
 		else
@@ -858,7 +838,7 @@ void multiplierinfo(void) {
 
 	mvprintw(0, 30, "REMAINING SECTIONS");
 	cnt = 0;
-	for (vert = 2; vert < 22; vert++) {
+	for (vert = 2; vert < LINES - 2; vert++) {
 	    if (cnt >= get_mult_count())
 		break;
 
@@ -897,7 +877,7 @@ void multiplierinfo(void) {
 
     attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
-    mvprintw(23, 22, " --- Press a key to continue --- ");
+    mvprintw(LINES - 2, 22, " --- Press a key to continue --- ");
 
     refreshp();
 
@@ -1074,7 +1054,6 @@ int debug_tty(void) {
 
 void wipe_display() {
     int j;
-    extern char backgrnd_str[];
 
     attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
