@@ -29,7 +29,9 @@
 
 #include "cw_utils.h"
 #include "get_time.h"
+#include "getwwv.h"
 #include "globalvars.h"		// Includes glib.h and tlf.h
+#include "muf.h"
 #include "printcall.h"
 #include "qsonr_to_str.h"
 #include "searchlog.h"		// Includes glib.h
@@ -38,15 +40,41 @@
 #include "ui_utils.h"
 
 
-void clear_display(void) {
-    extern char mode[];
+void show_header_line() {
+    extern cqmode_t cqmode;
     extern int cqdelay;
-    extern char headerline[];
+    extern const char headerline[];
+
+    char *mode = "";
+    switch (cqmode) {
+	case CQ:
+	    mode = "Log";
+	    break;
+	case S_P:
+	    mode = "S&P";
+	    break;
+	case AUTO_CQ:
+	    mode = "AUTO_CQ";
+	    break;
+	case KEYBOARD:
+	    mode = "Keyboard";
+	    break;
+	default:
+	    ;   // should not happen
+    }
+
+    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+    mvaddstr(0, 0, spaces(29));
+    mvprintw(0, 0, "  %-8s  S=%2i D=%i ", mode, GetCWSpeed(), cqdelay);
+    mvaddstr(0, 21, headerline);
+}
+
+
+void clear_display(void) {
     extern char terminal1[];
     extern char terminal2[];
     extern char terminal3[];
     extern char terminal4[];
-    extern char backgrnd_str[];
     extern char band[NBANDS][4];
     extern int bandinx;
     extern int trxmode;
@@ -56,25 +84,17 @@ void clear_display(void) {
     extern int cqww;
     extern int arrldx_usa;
     extern char comment[];
-    extern char hiscall[];
     extern int searchflg;
-    extern int m;
     extern struct tm *time_ptr;
     extern char whichcontest[];
     extern int no_rst;
 
     char time_buf[80];
-    char speedbuf[4] = "  ";
     int cury, curx;
 
-    snprintf(speedbuf, 3, "%2u", GetCWSpeed());
-
     getyx(stdscr, cury, curx);
 
-    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-    mvprintw(0, 0, "                             ");
-    mvprintw(0, 0, "  %s  S=%s D=%i ", mode, speedbuf, cqdelay);
-    mvprintw(0, 21, headerline);
+    show_header_line();
 
     attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
     mvaddstr(1, 0, terminal1);
@@ -110,21 +130,19 @@ void clear_display(void) {
     else
 	strftime(time_buf, 60, "DIG %d-%b-%y %H:%M ", time_ptr);
 
-    m = time_ptr->tm_mon;	/* month for muf calc */
+    month = time_ptr->tm_mon;	/* month for muf calc */
 
-    mvprintw(12, 3, time_buf);
+    mvaddstr(12, 3, time_buf);
 
     qsonr_to_str();
     mvaddstr(12, 23, qsonrstr);
 
     if (trxmode != SSBMODE) {
-
 	my_rst[2] = '9';
 	his_rst[2] = '9';
     } else {
 	my_rst[2] = ' ';
 	his_rst[2] = ' ';
-
     }
 
     if (no_rst) {
@@ -146,14 +164,15 @@ void clear_display(void) {
     }
 
     if (searchflg == SEARCHWINDOW)
-	searchlog(hiscall);
+	searchlog();
 
     printcall();
 
     attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-    mvprintw(LINES - 1, 0, backgrnd_str);
+    mvaddstr(LINES - 1, 0, backgrnd_str);
+    wwv_show_footer();
 
     attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
-    mvprintw(cury, curx, "");
+    move(cury, curx);
     refreshp();
 }
