@@ -21,6 +21,7 @@
 #ifndef EDITLOG_H
 #define EDITLOG_H
 
-int logedit(void);
+void edit(char *filename);
+void logedit(void);
 
 #endif /* EDITLOG_H */
