@@ -32,6 +32,7 @@
 #include "addspot.h"
 #include "cw_utils.h"
 #include "keyer.h"
+#include "keystroke_names.h"
 #include "lancode.h"
 #include "locator2longlat.h"
 #include "logit.h"
@@ -174,7 +175,7 @@ int getexchange(void) {
 
 	switch (x) {
 
-	    case 17: {	// Ctl-q (^Q)--Open QTC panel for receiving or sending QTCs
+	    case CTRL_Q: {	// Ctl-q (^Q)--Open QTC panel for receiving or sending QTCs
 		if (qtcdirection == 1 || qtcdirection == 3) {	// in case of QTC=RECV or QTC=BOTH
 		    qtc_main_panel(RECV);
 		}
@@ -191,10 +192,10 @@ int getexchange(void) {
 		x = KEY_LEFT;
 		continue;
 	    }
-	    case 1: {	// Ctl-a (^A)
+	    case CTRL_A: {	// Ctrl-A (^A)
 		addspot();
 		*comment = '\0';
-		x = 9;	// <Tab>
+		x = TAB;	// <Tab>
 		break;
 	    }
 
@@ -206,7 +207,7 @@ int getexchange(void) {
 		break;
 	    }
 
-	    case 27: {	// <Escape>
+	    case ESCAPE: {                // <Escape>
 		stoptx();			/* stop sending CW */
 		if (comment[0] != '\0') {	/* if comment not empty */
 		    /* drop exchange so far */
@@ -214,24 +215,48 @@ int getexchange(void) {
 		    i = 0;
 		} else {
 		    /* back to callinput */
-		    x = 9;	// <Tab>
+		    x = TAB;	// <Tab>
 		}
 		break;
 	    }
 
-	    case 160: {	// For CT compatibility Meta-<Space> (M- )
-		if (ctcomp != 0) {
-		    send_standard_message(1);		// F2
+	    /* I cannot find any reference for this key combination in my
+	     * CT ver 9 documentation.  As it is, most X window managers
+	     * will trap this combination for the window menu so would
+	     * only be useful on the console.
+	     *
+	     * - N0NB
+	     */
+	    /* case 160: {	// For CT compatibility Meta-<Space> (M- ) */
+	    /*     if (ctcomp != 0) { */
+	    /*         send_standard_message(1);		// F2 */
 
-		}
-		break;
-	    }
+	    /*     } */
+	    /*     break; */
+	    /* } */
 
-	    case '+': {	// for CT compatibility
+	    /* '+', send TU and log in CT mode */
+	    case '+': {
 		if ((ctcomp != 0) && (strlen(hiscall) > 2)) {
-		    send_standard_message(2);		/* F3 */
+		    if (comment[0] == '\0') {
+			x = -1;
+		    } else {
+			/* F4 (TU macro) */
+			send_standard_message(3);
+
+			/* log without additional message */
+			x = BACKSLASH;
+		    }
+		}
+		break;
+	    }
+
+	    /* <Insert>, send exchange in CT mode */
+	    case KEY_IC: {
+		if (ctcomp != 0) {
+		    /* F3 (RST macro) */
+		    send_standard_message(2);
 
-		    x = 92;	// '\'
 		}
 		break;
 	    }
@@ -251,12 +276,7 @@ int getexchange(void) {
 
 		break;
 	    }
-//	case KEY_F(11):
-//            {
-//                send_standard_message(10);        /* F11 */
 
-//                break;
-//            }
 	    case 176 ... 185: {	/* Alt-0 to Alt-9 */
 		send_standard_message(x - 162);	/* Messages 15-24 */
 
@@ -313,7 +333,7 @@ int getexchange(void) {
 
 	    }
 	    case ',':		// Keyboard Morse
-	    case 11: {	// Ctrl-K
+	    case CTRL_K: {	// Ctrl-K
 		mvprintw(5, 0, "");
 		keyer();
 		x = 0;
@@ -323,9 +343,15 @@ int getexchange(void) {
 	    case KEY_ENTER: {
 		/* log QSO immediately if CT compatible
 		 * or not in contest */
-		if ((ctcomp == 1) || (contest != 1))
-		    x = 92;	// '\'
-//                            if (dxped == 1) x = 92;
+		if ((ctcomp == 1) || (contest != 1)) {
+		    /* Don't log if exchange field is empty. */
+		    if (comment[0] == '\0') {
+			x = -1;
+		    } else {
+			/* Log without sending a message. */
+			x = BACKSLASH;
+		    }
+		}
 		break;
 	    }
 	}	// End switch
@@ -354,7 +380,8 @@ int getexchange(void) {
 	}
 
 	/* <Enter>, <Tab>, Ctl-K, '\' */
-	if (x == '\n' || x == KEY_ENTER || x == 9 || x == 11 || x == 92) {
+	if (x == '\n' || x == KEY_ENTER || x == TAB
+		|| x == CTRL_K || x == BACKSLASH) {
 
 	    if ((exchange_serial == 1 && comment[0] >= '0'
 		    && comment[0] <= '9')) {	/* align serial nr. */
@@ -431,14 +458,14 @@ int getexchange(void) {
 
 	    }
 
-	    if ((arrlss == 1) && (x != 9) && (strlen(section) < 2)) {
+	    if ((arrlss == 1) && (x != TAB) && (strlen(section) < 2)) {
 		mvprintw(13, 54, "section?");
 		mvprintw(12, 54, comment);
 		x = 0;
 	    } else if (((serial_section_mult == 1) || (sectn_mult == 1))
-		       && ((x != 9) && (strlen(section) < 1))) {
+		       && ((x != TAB) && (strlen(section) < 1))) {
 		if (serial_or_section == 0 || (serial_or_section == 1
-					       && country_found(hiscall) == 1)) {
+					       && country_found(hiscall))) {
 		    mvprintw(13, 54, "section?", section);
 		    mvprintw(12, 54, comment);
 		    refreshp();
@@ -469,7 +496,7 @@ int getexchange(void) {
 		if (strlen(comment) < 5) {
 		    mvprintw(13, 54, "state/prov?");
 		    mvprintw(12, 54, comment);
-		    if (x == '\n' || x == KEY_ENTER || x == 92) {
+		    if (x == '\n' || x == KEY_ENTER || x == BACKSLASH) {
 			x = 0;
 		    } else {
 			refreshp();
@@ -1095,23 +1122,23 @@ void exchange_edit(void) {
     l = strlen(comment);
     b = l - 1;
 
-    while ((i != 27) && (b <= strlen(comment))) {
+    while ((i != ESCAPE) && (b <= strlen(comment))) {
 	attroff(A_STANDOUT);
 	attron(COLOR_PAIR(C_HEADER));
 
-	mvprintw(12, 54, "                          ");
+	mvprintw(12, 54, spaces(80 - 54));
 	mvprintw(12, 54, comment);
 	mvprintw(12, 54 + b, "");
 
 	i = key_get();
 
 	// Ctrl-A (^A) or <Home>, move to beginning of comment field.
-	if (i == 1 || i == KEY_HOME) {
+	if (i == CTRL_A || i == KEY_HOME) {
 
 	    b = 0;
 
 	    // Ctrl-E (^E) or <End>, move to end of comment field, exit edit mode.
-	} else if (i == 5 || i == KEY_END) {
+	} else if (i == CTRL_E || i == KEY_END) {
 
 	    b = strlen(comment);
 	    break;
@@ -1155,7 +1182,7 @@ void exchange_edit(void) {
 	    }
 
 	    // <Escape> not received.
-	} else if (i != 27) {
+	} else if (i != ESCAPE) {
 
 	    // Promote lower case to upper case.
 	    if ((i >= 'a') && (i <= 'z'))
@@ -1176,7 +1203,7 @@ void exchange_edit(void) {
 		}
 
 	    } else if (i != 0)
-		i = 27;
+		i = ESCAPE;
 	}
     }
 
