@@ -28,6 +28,7 @@
 #include <pthread.h>
 
 #include "bands.h"
+#include "err_utils.h"
 #include "fldigixmlrpc.h"
 #include "gettxinfo.h"
 #include "tlf.h"
@@ -35,31 +36,24 @@
 #include "callinput.h"
 #include "bands.h"
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
+#include <hamlib/rig.h>
 
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
 #ifdef RIG_PASSBAND_NOCHANGE
 #define TLF_DEFAULT_PASSBAND RIG_PASSBAND_NOCHANGE
 #else
 #define TLF_DEFAULT_PASSBAND RIG_PASSBAND_NORMAL
 #endif
-#endif
 
-#ifdef HAVE_LIBHAMLIB
 extern RIG *my_rig;
 extern int cw_bandwidth;
 extern int trxmode;
-extern int rigmode;
+extern rmode_t rigmode;
 extern int digikeyer;
 extern rmode_t digi_mode;
-#endif
 
-extern float freq;
+extern freq_t freq;
 extern int bandinx;
-extern float bandfrequency[];
+extern freq_t bandfrequency[];
 
 extern int trx_control;
 extern unsigned char rigptt;
@@ -75,21 +69,14 @@ extern unsigned char rigptt;
  *  else - set rig frequency
  *
  */
-#ifdef HAVE_LIBHAMLIB
 static freq_t outfreq = 0;
-#else
-static int outfreq = 0;
-#endif
 
 static pthread_mutex_t outfreq_mutex = PTHREAD_MUTEX_INITIALIZER;
 
-
-#ifdef HAVE_LIBHAMLIB
 static double get_current_seconds();
-#endif
-static void handle_trx_bandswitch(int freq);
+static void handle_trx_bandswitch(const freq_t freq);
 
-void set_outfreq(double hertz) {
+void set_outfreq(freq_t hertz) {
     if (!trx_control) {
 	hertz = 0;      // no rig control, ignore request
     }
@@ -98,43 +85,45 @@ void set_outfreq(double hertz) {
     pthread_mutex_unlock(&outfreq_mutex);
 }
 
-double get_outfreq() {
+freq_t get_outfreq() {
     return outfreq;
 }
 
-static double get_and_reset_outfreq() {
+static freq_t get_and_reset_outfreq() {
     pthread_mutex_lock(&outfreq_mutex);
-    double f = outfreq;
+    freq_t f = outfreq;
     outfreq = 0.0;
     pthread_mutex_unlock(&outfreq_mutex);
     return f;
 }
 
+static rmode_t get_ssb_mode() {
+    // LSB below 14 MHz, USB above it
+    return (freq < bandcorner[BANDINDEX_20][0] ? RIG_MODE_LSB : RIG_MODE_USB);
+}
+
+static pbwidth_t get_cw_bandwidth() {
+    // use specified bandwidth (CWBANDWIDTH) if available
+    return (cw_bandwidth > 0 ? cw_bandwidth : TLF_DEFAULT_PASSBAND);
+}
+
 
 void gettxinfo(void) {
 
-#ifdef HAVE_LIBHAMLIB
     freq_t rigfreq;
     vfo_t vfo;
     pbwidth_t bwidth;
     int retval;
     int retvalmode;
     static double last_freq_time = 0.0;
-#else
-    float rigfreq;
-#endif
 
     static int oldbandinx;
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
     static int fldigi_carrier;
     static int fldigi_shift_freq;
-#endif
-
 
     if (!trx_control)
 	return;
 
-#ifdef HAVE_LIBHAMLIB
     /* CAT PTT wanted, available, inactive, and PTT On requested
      * bits 0, 1, and 3 set.
      */
@@ -160,15 +149,13 @@ void gettxinfo(void) {
 	/* Clear PTT active bit. */
 	rigptt &= ~(1 << 2);		/* 0x03 */
     }
-#endif
 
-    double reqf = get_and_reset_outfreq();  // get actual request
+    freq_t reqf = get_and_reset_outfreq();  // get actual request
 
     if (reqf == 0) {
 
 	rigfreq = 0.0;
 
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
 	double now = get_current_seconds();
 	if (now < last_freq_time + 0.2) {
 	    return;   // last read-out was within 200 ms, skip this query
@@ -180,7 +167,7 @@ void gettxinfo(void) {
 	    retval = rig_get_freq(my_rig, RIG_VFO_CURR, &rigfreq);
 	    if (trxmode == DIGIMODE && (digikeyer == GMFSK || digikeyer == FLDIGI)
 		    && retval == RIG_OK) {
-		retvalmode = rig_get_mode(my_rig, RIG_VFO_CURR, (rmode_t *)&rigmode, &bwidth);
+		retvalmode = rig_get_mode(my_rig, RIG_VFO_CURR, &rigmode, &bwidth);
 		if (retvalmode != RIG_OK) {
 		    rigmode = RIG_MODE_NONE;
 		}
@@ -203,14 +190,13 @@ void gettxinfo(void) {
 	    freq = 0.0;
 	    return;
 	}
-#endif
 
 
-	if (rigfreq >= 1800000.0) {
-	    freq = rigfreq / 1000.0;		/* kHz */
+	if (rigfreq >= bandcorner[0][0]) {
+	    freq = rigfreq; // Hz
 	}
 
-	bandinx = freq2band((unsigned int)(freq * 1000.0));
+	bandinx = freq2band((unsigned int)freq);
 
 	bandfrequency[bandinx] = freq;
 
@@ -221,44 +207,22 @@ void gettxinfo(void) {
 
     } else if (reqf == SETCWMODE) {
 
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
-	if (cw_bandwidth == 0) {
-	    retval =
-		rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_CW,
-			     TLF_DEFAULT_PASSBAND);
-	} else {
-	    retval =
-		rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_CW,
-			     cw_bandwidth);
-	}
-
-	if (retval != 0) {
-	    mvprintw(24, 0, "Problem with rig link!\n");
-	    refreshp();
-	    sleep(1);
-	}
-#endif
-
-    } else if (reqf == SETSSBMODE) {
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
-	if (freq > 13999.9)
-	    retval =
-		rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_USB,
-			     TLF_DEFAULT_PASSBAND);
-	else
-	    retval =
-		rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_LSB,
-			     TLF_DEFAULT_PASSBAND);
+	retval = rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_CW, get_cw_bandwidth());
 
 	if (retval != RIG_OK) {
-	    mvprintw(24, 0, "Problem with rig link!\n");
-	    refreshp();
-	    sleep(1);
+	    TLF_LOG_WARN("Problem with rig link!");
+	}
+
+    } else if (reqf == SETSSBMODE) {
+
+	retval = rig_set_mode(my_rig, RIG_VFO_CURR, get_ssb_mode(),
+			      TLF_DEFAULT_PASSBAND);
+
+	if (retval != RIG_OK) {
+	    TLF_LOG_WARN("Problem with rig link!");
 	}
-#endif
 
     } else if (reqf == SETDIGIMODE) {
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
 	rmode_t new_mode = digi_mode;
 	if (new_mode == RIG_MODE_NONE) {
 	    if (digikeyer == FLDIGI)
@@ -266,65 +230,49 @@ void gettxinfo(void) {
 	    else
 		new_mode = RIG_MODE_LSB;
 	}
-	retval =
-	    rig_set_mode(my_rig, RIG_VFO_CURR, new_mode,
-		TLF_DEFAULT_PASSBAND);
+	retval = rig_set_mode(my_rig, RIG_VFO_CURR, new_mode,
+			      TLF_DEFAULT_PASSBAND);
 
 	if (retval != RIG_OK) {
-	    mvprintw(24, 0, "Problem with rig link!\n");
-	    refreshp();
-	    sleep(1);
+	    TLF_LOG_WARN("Problem with rig link!");
 	}
-#endif
 
     } else if (reqf == RESETRIT) {
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
 	retval = rig_set_rit(my_rig, RIG_VFO_CURR, 0);
 
 	if (retval != RIG_OK) {
-	    mvprintw(24, 0, "Problem with rig link!\n");
-	    refreshp();
-	    sleep(1);
+	    TLF_LOG_WARN("Problem with rig link!");
 	}
-#endif
 
     } else {
 	// set rig frequency to `reqf'
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
 	retval = rig_set_freq(my_rig, RIG_VFO_CURR, (freq_t) reqf);
 
 	if (retval != RIG_OK) {
-	    mvprintw(24, 0, "Problem with rig link: set frequency!\n");
-	    refreshp();
-	    sleep(1);
+	    TLF_LOG_WARN("Problem with rig link: set frequency!");
 	}
-#endif
 
     }
 
 }
 
 
-#ifdef HAVE_LIBHAMLIB
 static double get_current_seconds() {
     struct timeval tv;
     gettimeofday(&tv, NULL);
     return tv.tv_sec + tv.tv_usec / 1e6;
 }
-#endif
 
 
-static void handle_trx_bandswitch(int freq) {
+static void handle_trx_bandswitch(const freq_t freq) {
 
     send_bandswitch(freq);
 
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
-
     rmode_t mode = RIG_MODE_NONE;           // default: no change
     pbwidth_t width = TLF_DEFAULT_PASSBAND; // passband width, in Hz
 
     if (trxmode == SSBMODE) {
-	mode = (freq < 14000 ? RIG_MODE_LSB : RIG_MODE_USB);
+	mode = get_ssb_mode();
     } else if (trxmode == DIGIMODE) {
 	if ((rigmode & (RIG_MODE_LSB | RIG_MODE_USB | RIG_MODE_RTTY | RIG_MODE_RTTYR))
 		!= rigmode) {
@@ -332,9 +280,7 @@ static void handle_trx_bandswitch(int freq) {
 	}
     } else {
 	mode = RIG_MODE_CW;
-	if (cw_bandwidth != 0) {
-	    width = cw_bandwidth;
-	}
+	width = get_cw_bandwidth();
     }
 
     if (mode == RIG_MODE_NONE) {
@@ -344,12 +290,8 @@ static void handle_trx_bandswitch(int freq) {
     int retval = rig_set_mode(my_rig, RIG_VFO_CURR, mode, width);
 
     if (retval != RIG_OK) {
-	mvprintw(24, 0,
-		 "Problem with rig link: set mode!\n");
-	refreshp();
-	sleep(1);
+	TLF_LOG_WARN("Problem with rig link!");
     }
 
-#endif
 }
 
