@@ -34,15 +34,17 @@
 #define QTCSENTRY 57
 #define QTCFLAG 58
 
+#include <hamlib/rig.h>
+
 int lanrecv_init(void);
 int lan_recv_close(void);
 int lan_recv(void);
 int lan_send_init(void);
 int lan_send_close(void);
-int lan_send(char *buffer) ;
+int lan_send(char *lanbuffer) ;
 int send_lan_message(int opcode, char *message);
-int talk(void);
-int send_freq(float freq);
+void talk(void);
+int send_freq(freq_t freq);
 int send_time(void) ;
 
 #endif /* LANCODE_H */
