@@ -31,6 +31,7 @@
 #include "clear_display.h"
 #include "getexchange.h"
 #include "keyer.h"
+#include "keystroke_names.h"
 #include "log_to_disk.h"
 #include "printcall.h"
 #include "recall_exchange.h"
@@ -49,10 +50,9 @@ void refresh_comment(void);
 void change_mode(void);
 
 void logit(void) {
-    extern char mode[];
     extern int trxmode;
     extern char hiscall[];
-    extern int cqmode;
+    extern cqmode_t cqmode;
     extern int contest;
     extern char ph_message[14][80];
     extern char comment[];
@@ -73,7 +73,7 @@ void logit(void) {
     int cury, curx;
     int qrg_out = 0;
 
-    strcpy(mode, "Log     ");
+    cleanup();
     clear_display();
     defer_store = 0;
 
@@ -93,11 +93,11 @@ void logit(void) {
 
 	    if ((trxmode == CWMODE || trxmode == DIGIMODE)
 		    && (callreturn == '\n') && ctcomp == 1) {
-		callreturn = 92; 	/* '\' */
+		callreturn = BACKSLASH;
 		strcpy(comment, cqzone);
 	    }
 
-	    if ((callreturn == 9 || callreturn == 32)) {
+	    if ((callreturn == TAB || callreturn == SPACE)) {
 		callreturn = getexchange();
 	    }
 
@@ -195,7 +195,7 @@ void logit(void) {
 		}
 	    }
 
-	    if ((callreturn == 92) && (*hiscall != '\0')) {
+	    if ((callreturn == BACKSLASH) && (*hiscall != '\0')) {
 		defer_store = 0;
 
 		log_to_disk(false);
@@ -205,7 +205,7 @@ void logit(void) {
 		HideSearchPanel();
 	    }
 
-	    if (callreturn == 11 || callreturn == 44) {	/*  CTRL K  */
+	    if (callreturn == CTRL_K || callreturn == 44) {	/*  CTRL K  */
 		getyx(stdscr, cury, curx);
 		mvprintw(5, 0, "");
 		keyer();
@@ -225,13 +225,12 @@ void refresh_comment(void) {
 
     attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
-    mvprintw(12, 54, "                          ");
+    mvprintw(12, 54, spaces(80 - 54));
     mvprintw(12, 54, comment);
 }
 
 void change_mode(void) {
-    extern char mode[];
-    extern int cqmode;
+    extern cqmode_t cqmode;
 
     /* switch to other mode */
     if (cqmode == CQ) {
@@ -241,13 +240,5 @@ void change_mode(void) {
     }
 
     /* and show new mode */
-    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-
-    if (cqmode == CQ) {
-	mvprintw(0, 2, "Log     ");
-	strcpy(mode, "Log     ");
-    } else {
-	mvprintw(0, 2, "S&P     ");
-	strcpy(mode, "S&P     ");
-    }
+    show_header_line();
 }
