@@ -20,13 +20,14 @@
  */
 
 
+#include <argp.h>
 #include <ctype.h>
+#include <hamlib/rig.h>
 #include <pthread.h>
 #include <stdlib.h>
 #include <string.h>
 #include <termios.h>
 #include <unistd.h>
-#include <argp.h>
 
 #include "addmult.h"
 #include "background_process.h"
@@ -62,7 +63,6 @@
 #include "readcabrillo.h"
 
 #include <config.h>
-#include <hamlib/rig.h>
 
 
 SCREEN *mainscreen;
@@ -86,7 +86,7 @@ int tlfcolors[8][2] = { {COLOR_BLACK, COLOR_WHITE},
     {COLOR_WHITE, COLOR_BLACK}
 };
 int debugflag = 0;
-int editor = EDITOR_JOE;
+char *editor_cmd = NULL;
 int tune_val = 0;
 int use_bandoutput = 0;
 int no_arrows = 0;
@@ -115,7 +115,6 @@ int pfxmult = 0;
 int pfxmultab = 0;
 int exc_cont = 0;
 int manise80;
-int other_flg;
 int one_point = 0;
 int two_point = 0;
 int three_point = 0;
@@ -129,13 +128,13 @@ int my_country_points = -1;
 int my_cont_points = -1;
 int dx_cont_points = -1;
 char countrylist[255][6];
-int countrylist_only = 0;
+bool countrylist_only = false;
 int countrylist_points = -1;
 char continent_multiplier_list[7][3]; // SA, NA, EU, AF, AS and OC
 int continentlist_points = -1;
-int continentlist_only = 0;
-int exclude_multilist_type = 0;
-int mult_side = 0;
+bool continentlist_only = false;
+int exclude_multilist_type = EXCLUDE_NONE;
+bool mult_side = false;
 /* end LZ3NY mods */
 
 int portable_x2 = 0;
@@ -197,7 +196,7 @@ int cluster = NOCLUSTER;	/* 0 = OFF, 1 = FOLLOW, 2  = spots  3 = all */
 int clusterlog = 0;		/* clusterlog on/off */
 int searchflg = 0;		/* 1  = display search  window */
 int show_time = 0;
-int cqmode = CQ;		/* 1  = CQ  0 = S&P  */
+cqmode_t cqmode = CQ;
 int demode = 0;			/* 1 =  send DE  before s&p call  */
 int contest = 0;		/* 0 =  General,  1  = contest */
 int announcefilter = FILTER_ANN; /*  filter cluster  announcements */
@@ -279,9 +278,8 @@ int early_started = 0;			/**< 1 if sending call started early,
 char lastcall[20];
 char qsonrstr[5] = "0001";
 char band[NBANDS][4] =
-{ "160", " 80", " 40", " 30", " 20", " 17", " 15", " 12", " 10", "???" };
+{ "160", " 80", " 60", " 40", " 30", " 20", " 17", " 15", " 12", " 10", "???" };
 char comment[80];
-char mode[20] = "Log     ";
 char cqzone[3] = "";
 char mycqzone[3] = "";
 char ituzone[3] = "";
@@ -334,7 +332,6 @@ int commentfield = 0;		/* 1 if we are in comment/excahnge input */
 /*-------------------------------------packet-------------------------------*/
 char spot_ptr[MAX_SPOTS][82];		/* Array of cluster spot lines */
 int nr_of_spots;			/* Anzahl Lines in spot_ptr array */
-char lastwwv[120] = "";
 int packetinterface = 0;
 int fdSertnc = 0;
 int tncport = 1;
@@ -410,20 +407,17 @@ pid_t pid;
 struct tm *time_ptr, time_ptr_cabrillo;
 
 freq_t freq;
-freq_t mem;
 int logfrequency = 0;
 int rit;
 int trx_control = 0;
-int showfreq = 0;
 freq_t bandfrequency[NBANDS] = {
-    1830000, 3525000, 7010000, 10105000, 14025000, 18070000, 21025000, 24900000,
+    1830000, 3525000, 5352000, 7010000, 10105000, 14025000, 18070000, 21025000, 24900000,
     28025000, 0.
 };
 
-char headerline[81] =
-    "   1=CQ  2=DE  3=RST 4=73  5=HIS  6=MY  7=B4   8=AGN  9=?  \n";
-char backgrnd_str[81] =
-    "                                                                                ";
+const char headerline[] =
+    "   1=CQ  2=DE  3=RST 4=73  5=HIS  6=MY  7=B4   8=AGN  9=?  ";
+const char *backgrnd_str;
 
 char logline_edit[5][LOGLINELEN + 1];
 
@@ -439,8 +433,6 @@ double QTH_Long = -7.;
 double DEST_Lat = 51.;
 double DEST_Long = 1.;
 
-double r = 50;
-int m = 1;
 char hiscountry[40];
 
 int this_second;
@@ -454,8 +446,8 @@ int no_trx_control = 0;		/* set if tlf is called with '-r' */
 int convert_cabrillo = 0;       /* set if the arg input is a cabrillo */
 int do_cabrillo = 0;		/* actually converting cabrillo file to Tlf log */
 
-int bandweight_points[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 0};
-int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 0};
+int bandweight_points[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0};
+int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0};
 
 pthread_t background_thread;
 static struct termios oldt, newt;
@@ -657,7 +649,7 @@ int databases_load() {
 
     if (*call == '\0') {
 	showmsg
-	    ("WARNING: No callsign defined in logcfg.dat! exiting...\n");
+	("WARNING: No callsign defined in logcfg.dat! exiting...\n");
 	return EXIT_FAILURE;
     }
 
@@ -837,22 +829,14 @@ void show_GPL() {
     printw("             T    L      FFFFF\n");
     printw("             T    L      F    \n");
     printw("             T    LLLLL  F    \n");
-    printw
-	("\n\nThis program is copyright 2002, 2003, 2004 by Rein Couperus, PA0R\n\n");
-    printw
-	("It is free software; you can redistribute it and/or modify it under the terms\n");
-    printw
-	("of the GNU General Public License as published by the Free Software Foundation;\n");
-    printw
-	("either version 2 of the License, or (at your option) any later version.\n\n");
-    printw
-	("This program is distributed in the hope that it will be useful, but\n");
-    printw
-	("WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n");
-    printw
-	("or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License\n");
-    printw
-	("for more details.\n");
+    printw("\n\nThis program is copyright 2002, 2003, 2004 by Rein Couperus, PA0R\n\n");
+    printw("It is free software; you can redistribute it and/or modify it under the terms\n");
+    printw("of the GNU General Public License as published by the Free Software Foundation;\n");
+    printw("either version 2 of the License, or (at your option) any later version.\n\n");
+    printw("This program is distributed in the hope that it will be useful, but\n");
+    printw("WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n");
+    printw("or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License\n");
+    printw("for more details.\n");
 
     refreshp();
 }
@@ -905,11 +889,13 @@ void tlf_cleanup() {
 /* ------------------------------------------------------------------------*/
 /*     Main loop of the program			                           */
 /* ------------------------------------------------------------------------*/
-
 int main(int argc, char *argv[]) {
     int j;
     int ret;
     char welcome[80];
+
+    backgrnd_str = spaces(80);
+
     sprintf(welcome, "        Welcome to %s by PA0R!!", argp_program_version);
 
     argp_parse(&argp, argc, argv, 0, 0, NULL);  // parse options
@@ -978,7 +964,7 @@ int main(int argc, char *argv[]) {
     lan_init();
     keyer_init();
 
-    scroll_log();		/* read the last 5  log lines and set the qso number */
+    scroll_log();		/* read the last 5  log lines and set the next serial number */
     nr_qsos = readcalls();	/* read the logfile for score and dupe */
 
     checkparameters();		/* check .paras file */
@@ -995,7 +981,6 @@ int main(int argc, char *argv[]) {
     }
     refreshp();
 
-    getwwv();			/* get the latest wwv info from packet */
     bm_init();			/* initialize bandmap */
 
     atexit(tlf_cleanup); 	/* register cleanup function */
