@@ -22,6 +22,7 @@
 
 
 #include <ctype.h>
+#include <hamlib/rig.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdbool.h>
@@ -32,6 +33,7 @@
 #include "fldigixmlrpc.h"
 #include "getctydata.h"
 #include "getpx.h"
+#include "getwwv.h"
 #include "lancode.h"
 #include "locator2longlat.h"
 #include "parse_logcfg.h"
@@ -42,7 +44,6 @@
 #include "searchlog.h"
 
 #include <config.h>
-#include <hamlib/rig.h>
 
 
 extern int cwkeyer;
@@ -58,9 +59,9 @@ extern int tncport;
 extern int shortqsonr;
 extern char *cabrillo;
 extern rmode_t digi_mode;
+extern int ctcomp;
 
-int exist_in_country_list();
-int continent_found();
+bool exist_in_country_list();
 
 void KeywordRepeated(char *keyword);
 void KeywordNotSupported(char *keyword);
@@ -94,6 +95,9 @@ int read_logcfg(void) {
     node = 0;
     shortqsonr = 0;
 
+    /* Disable CT Mode until CTCOMPATIBLE is defined. */
+    ctcomp = 0;
+
     for (i = 0; i < 25; i++) {
 	if (digi_message[i] != NULL) {
 	    free(digi_message[i]);
@@ -155,7 +159,7 @@ int parse_configfile(FILE *fp) {
 
 /** convert band string into index number (0..NBANDS-1) */
 int getidxbybandstr(char *confband) {
-    static char bands_strings[NBANDS][4] = {"160", "80", "40", "30", "20", "17", "15", "12", "10"};
+    static char bands_strings[NBANDS][4] = {"160", "80", "60", "40", "30", "20", "17", "15", "12", "10"};
     int i;
 
     g_strchomp(confband);
@@ -211,8 +215,7 @@ int parse_logcfg(char *inputbuffer) {
     extern int weight;
     extern int txdelay;
     extern char tonestr[];
-    extern int showfreq;
-    extern int editor;
+    extern char *editor_cmd;
     extern int partials;
     extern int use_part;
     extern int mixedmode;
@@ -221,7 +224,6 @@ int parse_logcfg(char *inputbuffer) {
     extern int packetinterface;
     extern int tncport;
     extern int tnc_serial_rate;
-    extern char lastwwv[];
     extern int serial_rate;
     extern rig_model_t myrig_model;
     extern char *rigportname;
@@ -242,7 +244,6 @@ int parse_logcfg(char *inputbuffer) {
     extern int call_update;
     extern int timeoffset;
     extern int time_master;
-    extern int ctcomp;
     extern char multsfile[];
     extern int multlist;
     extern int universal;
@@ -276,20 +277,16 @@ int parse_logcfg(char *inputbuffer) {
     extern int serial_or_section;
 
     /* LZ3NY mods */
-    extern int mult_side;
     extern int my_country_points;
     extern int my_cont_points;
     extern int dx_cont_points;
     extern int countrylist_points;
-    extern int countrylist_only;
+    extern bool countrylist_only;
     extern int continentlist_points;
-    extern int continentlist_only;
+    extern bool continentlist_only;
     char c_temp[11];
-    extern int my_cont_points;
-    extern int dx_cont_points;
-    extern int mult_side;
+    extern bool mult_side;
     extern char countrylist[][6];
-
     extern char continent_multiplier_list[7][3];
     extern int exclude_multilist_type;
 
@@ -367,7 +364,7 @@ int parse_logcfg(char *inputbuffer) {
 	"TXDELAY",
 	"SUNSPOTS",
 	"SFI",
-	"SHOW_FREQUENCY",
+	"SHOW_FREQUENCY",                       /* deprecated */
 	"EDITOR",		/* 45 */
 	"PARTIALS",
 	"USEPARTIALS",
@@ -594,9 +591,7 @@ int parse_logcfg(char *inputbuffer) {
     char **fields;
     char teststring[80];
     char buff[40];
-    char outputbuff[80];
     int ii;
-    char *j;
     int jj, hh;
     char *tk_ptr;
 
@@ -894,50 +889,18 @@ int parse_logcfg(char *inputbuffer) {
 	}
 	case 42: {
 	    PARAMETER_NEEDED(teststring);
-	    buff[0] = '\0';
-	    strcat(buff, fields[1]);
-	    outputbuff[0] = '\0';
-	    sprintf(outputbuff, "WWV R=%d\n", atoi(buff));
-	    strcpy(lastwwv, outputbuff);
+            wwv_set_r(atoi(fields[1]));
 	    break;
 	}
 	case 43: {
 	    PARAMETER_NEEDED(teststring);
-	    buff[0] = '\0';
-	    strcat(buff, fields[1]);
-	    outputbuff[0] = '\0';
-	    sprintf(outputbuff, "WWV SFI=%d\n", atoi(buff));
-	    strcpy(lastwwv, outputbuff);
-	    break;
-	}
-	case 44: {
-	    showfreq = 1;
+            wwv_set_sfi(atoi(fields[1]));
 	    break;
 	}
 	case 45: {
 	    PARAMETER_NEEDED(teststring);
 	    buff[0] = '\0';
-	    strcat(buff, fields[1]);
-	    if ((strncmp(buff, "mcedit", 6) == 0)
-		    || (strncmp(buff, "mc", 2) == 0)
-		    || (strncmp(buff, "MC", 2) == 0)) {
-		editor = EDITOR_MC;
-		break;
-	    }
-
-	    j = strstr(fields[1], "joe");
-	    if (j != NULL) {
-		editor = EDITOR_JOE;
-		break;
-	    }
-	    j = strstr(fields[1], "vi");
-	    if (j != NULL) {
-		editor = EDITOR_VI;
-		break;
-	    } else {
-		editor = EDITOR_E3;
-		break;
-	    }
+	    editor_cmd = g_strdup(g_strchomp(fields[1]));
 	}
 	case 46: {
 	    partials = 1;
@@ -1182,8 +1145,8 @@ int parse_logcfg(char *inputbuffer) {
 
 	    int counter = 0;
 	    static char country_list_raw[50] = ""; 	/* use only first
-						   	COUNTRY_LIST
-						   	definition */
+						       COUNTRY_LIST
+						       definition */
 	    char temp_buffer[255] = "";
 	    char buffer[255] = "";
 	    FILE *fp;
@@ -1256,9 +1219,9 @@ int parse_logcfg(char *inputbuffer) {
 	    break;
 	}
 	case 97: {		// COUNTRY_LIST_ONLY
-	    countrylist_only = 1;
+	    countrylist_only = true;
 	    if (mult_side == 1)
-		countrylist_only = 0;
+		countrylist_only = false;
 
 	    break;
 	}
@@ -1301,7 +1264,7 @@ int parse_logcfg(char *inputbuffer) {
 	    if (verbose) {
 		gchar *tmp;
 		tmp = g_strdup_printf("  Phone message #%d is %s", ii - 103,
-		     ph_message[ii - 103]);	// (W9WI)
+				      ph_message[ii - 103]);	// (W9WI)
 		showmsg(tmp);
 		g_free(tmp);
 	    }
@@ -1568,8 +1531,8 @@ int parse_logcfg(char *inputbuffer) {
 
 	    int counter = 0;
 	    static char cont_multiplier_list[50] = ""; 	/* use only first
-						   	CONTINENT_LIST
-						   	definition */
+						       CONTINENT_LIST
+						       definition */
 	    char temp_buffer[255] = "";
 	    char buffer[255] = "";
 	    FILE *fp;
@@ -1631,7 +1594,7 @@ int parse_logcfg(char *inputbuffer) {
 	    break;
 	}
 	case 165: {		// CONTINENT_LIST_ONLY
-	    continentlist_only = 1;
+	    continentlist_only = true;
 	    break;
 	}
 
@@ -1746,7 +1709,7 @@ int parse_logcfg(char *inputbuffer) {
 	    if (verbose) {
 		gchar *tmp;
 		tmp = g_strdup_printf("  QTC RECV phone message #%d is %s",
-		    ii - 194, qtc_phrecv_message[ii - 194]);
+				      ii - 194, qtc_phrecv_message[ii - 194]);
 		showmsg(tmp);
 		g_free(tmp);
 	    }
@@ -1758,7 +1721,7 @@ int parse_logcfg(char *inputbuffer) {
 	    if (verbose) {
 		gchar *tmp;
 		tmp = g_strdup_printf("  QTC SEND phone message #%d is %s",
-		    ii - 208, qtc_phrecv_message[ii - 208]);
+				      ii - 208, qtc_phrecv_message[ii - 208]);
 		showmsg(tmp);
 		g_free(tmp);
 	    }
@@ -1808,7 +1771,7 @@ int parse_logcfg(char *inputbuffer) {
 		    sleep(5);
 		    exit(1);
 		}
-		exclude_multilist_type = 1;
+		exclude_multilist_type = EXCLUDE_CONTINENT;
 	    } else if (strcmp(g_strchomp(fields[1]), "COUNTRYLIST") == 0) {
 		if (strlen(countrylist[0]) == 0) {
 		    showmsg
@@ -1816,7 +1779,7 @@ int parse_logcfg(char *inputbuffer) {
 		    sleep(5);
 		    exit(1);
 		}
-		exclude_multilist_type = 2;
+		exclude_multilist_type = EXCLUDE_COUNTRY;
 	    } else {
 		showmsg
 		("WARNING: choose one of these for EXCLUDE_MULTILIST: CONTINENTLIST, COUNTRYLIST");
@@ -2047,7 +2010,7 @@ void Complain(char *msg) {
 
 /** Complain about duplicate keyword */
 void KeywordRepeated(char *keyword) {
-    char msgbuffer[100];
+    char msgbuffer[128];
     sprintf(msgbuffer,
 	    "Keyword '%s' repeated more than once.\n",
 	    keyword);
@@ -2056,7 +2019,7 @@ void KeywordRepeated(char *keyword) {
 
 /** Complain about not supported keyword */
 void KeywordNotSupported(char *keyword) {
-    char msgbuffer[100];
+    char msgbuffer[192];
     sprintf(msgbuffer,
 	    "Keyword '%s' not supported. See man page.\n",
 	    keyword);
@@ -2065,7 +2028,7 @@ void KeywordNotSupported(char *keyword) {
 
 /** Complain about missing parameter */
 void ParameterNeeded(char *keyword) {
-    char msgbuffer[100];
+    char msgbuffer[192];
     sprintf(msgbuffer,
 	    "Keyword '%s' must be followed by an parameter ('=....'). See man page.\n",
 	    keyword);
@@ -2074,7 +2037,7 @@ void ParameterNeeded(char *keyword) {
 
 /** Complain about wrong parameter format */
 void WrongFormat(char *keyword) {
-    char msgbuffer[100];
+    char msgbuffer[192];
     sprintf(msgbuffer,
 	    "Wrong parameter format for keyword '%s'. See man page.\n",
 	    keyword);
