@@ -25,8 +25,8 @@
 #include "cabrillo_utils.h"
 
 void store_qtc(char *loglineptr, int direction, char *filename);
-int log_recv_qtc_to_disk(int qtcnr);
-int log_sent_qtc_to_disk(int qtcnr);
+int log_recv_qtc_to_disk(int qsonr);
+int log_sent_qtc_to_disk(int qsonr);
 void make_qtc_logline(struct read_qtc_t qtc_line, char *fname);
 
 #endif /* end of include guard: LOG_RECV_QTC_TO_DISK_H */
