@@ -33,6 +33,7 @@
 #include "get_time.h"
 #include "ignore_unused.h"
 #include "keyer.h"
+#include "keystroke_names.h"
 #include "lancode.h"
 #include "nicebox.h"		// Includes curses.h
 #include "qtc_log.h"
@@ -369,8 +370,7 @@ void prepare_for_recv() {
     }
 
     /* save the previous qtc callsign */
-    strncpy(prevqtccall, qtcreclist.callsign, strlen(qtcreclist.callsign));
-    prevqtccall[strlen(qtcreclist.callsign)] = '\0';
+    g_strlcpy(prevqtccall, qtcreclist.callsign, sizeof(prevqtccall));
     qtccallsign = qtcreclist.callsign;
 
     /* save the address of the counter of receive QTC block */
@@ -396,8 +396,7 @@ void prepare_for_send() {
     }
 
     /* save the current callsign to previous call variable */
-    strncpy(prevqtccall, qtclist.callsign, strlen(qtclist.callsign));
-    prevqtccall[strlen(qtclist.callsign)] = '\0';
+    g_strlcpy(prevqtccall, qtclist.callsign, sizeof(prevqtccall));
     qtccallsign = qtclist.callsign;
 
     /* save the address of the counter of SEND qtc structure */
@@ -445,7 +444,7 @@ void qtc_main_panel(int direction) {
 
     x = -1;
     /* main loop */
-    while (x != 27) {
+    while (x != ESCAPE) {
 
 	while (x < 1) {
 
@@ -459,10 +458,8 @@ void qtc_main_panel(int direction) {
 	}
 
 	switch (x) {
-	    //case 227:		// ALT-c
-
 	    // Ctrl-T (^T)
-	    case 20:
+	    case CTRL_T:
 		if (trxmode == DIGIMODE) {
 		    show_rtty_lines();
 		}
@@ -620,8 +617,7 @@ void qtc_main_panel(int direction) {
 			    get_time();
 			    tempc[0] = '\0';
 			    strftime(tempc, 40, "%d-%b-%y %H:%M", time_ptr);
-			    strncpy(qtcreclist.qtclines[currqtc].receivedtime, tempc, 15);
-			    qtcreclist.qtclines[currqtc].receivedtime[15] = '\0';
+			    g_strlcpy(qtcreclist.qtclines[currqtc].receivedtime, tempc, 16);
 			    qtcreclist.qtclines[currqtc].status = 2;
 			    show_status(currqtc);
 			    if (currqtc < *qtccount) {
@@ -679,7 +675,7 @@ void qtc_main_panel(int direction) {
 				    play_file(qtc_phrecv_message[9]);
 				}
 			    }
-			    x = 27;	// <Escape> close the window
+			    x = ESCAPE;	// <Escape> close the window
 			}
 		    }
 		    if (direction == SEND && trxmode != DIGIMODE) {
@@ -688,7 +684,7 @@ void qtc_main_panel(int direction) {
 			    get_time();
 			    tempc[0] = '\0';
 			    strftime(tempc, 40, "%d-%b-%y %H:%M", time_ptr);
-			    strncpy(qtclist.qtclines[activefield - 3].senttime, tempc, 15);
+			    g_strlcpy(qtclist.qtclines[activefield - 3].senttime, tempc, 16);
 			    qtclist.qtclines[activefield - 3].senttime[15] = '\0';
 			    qtclist.totalsent++;
 			}
@@ -747,10 +743,9 @@ void qtc_main_panel(int direction) {
 			int ql;
 			tmess[0] = '\0';
 			if (tlen > 0 && strncmp(qtc_send_msgs[1] + tlen, "sr/nr", 5) == 0) {
-			    tempc[0] = '\0';
-			    strncpy(tempc, qtc_send_msgs[1], tlen - 1);
-			    tempc[tlen - 1] = '\0';
-			    sprintf(tmess, "%s %d/%d %s %d/%d\n", tempc, qtclist.serial, *qtccount, tempc,
+			    g_strlcpy(tempc, qtc_send_msgs[1], tlen);
+			    sprintf(tmess, "%s %d/%d %s %d/%d\n",
+				    tempc, qtclist.serial, *qtccount, tempc,
 				    qtclist.serial, *qtccount);
 			}
 			timec[0] = '\0';
@@ -759,8 +754,7 @@ void qtc_main_panel(int direction) {
 
 			for (ql = 0; ql < *qtccount; ql++) {
 			    qtclist.qtclines[ql].sent = 1;
-			    strncpy(qtclist.qtclines[ql].senttime, timec, 15);
-			    qtclist.qtclines[ql].senttime[15] = '\0';
+			    g_strlcpy(qtclist.qtclines[ql].senttime, timec, 16);
 			    qtclist.totalsent++;
 
 			    tempc[0] = '\0';
@@ -799,7 +793,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // Ctrl-S (^S), save QTC
-	    case 19:
+	    case CTRL_S:
 		if (qtccurrdirection == SEND && *qtccount > 0
 			&& qtclist.totalsent == *qtccount) {
 		    log_sent_qtc_to_disk(nr_qsos);
@@ -809,7 +803,7 @@ void qtc_main_panel(int direction) {
 		    qtccallsign[0] = '\0';
 		    refreshp();
 		    sleep(1);
-		    x = 27;	// <Escape> close the window
+		    x = ESCAPE;	// <Escape> close the window
 
 		}
 		if (qtccurrdirection == RECV && trxmode == DIGIMODE) {
@@ -825,7 +819,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // Ctrl-E (^E), end capture
-	    case 5:
+	    case CTRL_E:
 		if (qtccurrdirection == RECV && trxmode == DIGIMODE) {
 		    qtc_ry_capture = 0;
 		    wattr_get(qtcwin, &attributes, &cpair, NULL);
@@ -873,12 +867,10 @@ void qtc_main_panel(int direction) {
 			    qtc_send_msgs[x - KEY_F(1)][strlen(qtc_send_msgs[x - KEY_F(1)]) - 1] = 0;
 			}
 			tlen = strlen(qtc_send_msgs[x - KEY_F(1)]) - 5; // len("sr/nr") = 5
-			char tmess[40];
+			char tmess[60];
 			tmess[0] = '\0';
 			if (tlen > 0 && strncmp(qtc_send_msgs[x - KEY_F(1)] + tlen, "sr/nr", 5) == 0) {
-			    tempc[0] = '\0';
-			    strncpy(tempc, qtc_send_msgs[x - KEY_F(1)], tlen - 1);
-			    tempc[tlen - 1] = '\0';
+			    g_strlcpy(tempc, qtc_send_msgs[x - KEY_F(1)], tlen);
 			    sprintf(tmess, "%s %d/%d ", tempc, qtclist.serial, *qtccount);
 			    sendmessage(tmess);
 			} else if ((activefield - 3) >= 0) {
@@ -939,7 +931,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // <Tab>
-	    case 9:
+	    case TAB:
 		if (direction == RECV) {
 		    if (trxmode == DIGIMODE) {
 			if (activefield == 32) {
@@ -1022,7 +1014,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // <Space>
-	    case ' ':
+	    case SPACE:
 		if (DIRCLAUSE) {
 		    if (direction == RECV) {
 			if (activefield > 2) {
@@ -1126,7 +1118,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // Ctrl-L (^L), mark callsign for late QTC
-	    case 12:
+	    case CTRL_L:
 		if (strlen(g_strstrip(qtccallsign)) > 3) {
 		    qtc_inc(g_strstrip(qtccallsign), QTC_LATER);
 		    sprintf(tempc, "%s;L\n", qtccallsign);
@@ -1135,7 +1127,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // Ctrl-N (^N), mark callsign for explicit NO QTC
-	    case 14:
+	    case CTRL_N:
 		if (strlen(g_strstrip(qtccallsign)) > 3) {
 		    qtc_inc(g_strstrip(qtccallsign), QTC_NO);
 		    sprintf(tempc, "%s;N\n", qtccallsign);
@@ -1144,7 +1136,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // Ctrl-F (^F), fill time fields with first 2 chars
-	    case 6:
+	    case CTRL_F:
 		if (activefield > 2) {
 		    fill_qtc_times(qtcreclist.qtclines[(activefield - 3) / 3].time);
 		    showfield(activefield);
@@ -1152,7 +1144,7 @@ void qtc_main_panel(int direction) {
 		break;
 
 	    // Ctrl-R (^R), start/stop recording
-	    case 18:
+	    case CTRL_R:
 		if (direction == RECV) {
 		    if (record_run < 0) {
 			start_qtc_recording();
@@ -1163,7 +1155,7 @@ void qtc_main_panel(int direction) {
 		}
 	}
 	refreshp();
-	if (x != 27) {
+	if (x != ESCAPE) {
 	    x = 0;
 	}
     }
@@ -1355,7 +1347,7 @@ void delete_from_field(int dir) {
 	if (strlen(qtccallsign) > 0) {
 	    sprintf(fieldval, "%s", qtccallsign);
 	    shift_left(fieldval, dir);
-	    strncpy(qtccallsign, fieldval, strlen(fieldval));
+	    g_strlcpy(qtccallsign, fieldval, QTC_CALL_SIZE);
 	    qtccallsign[strlen(fieldval)] = '\0';
 	    recalc_qtclist();
 	    showfield(0);
@@ -1547,8 +1539,7 @@ void show_help_msg(int msgidx) {
     for (i = 0; i < 12 && j < 12; i++) {
 	if (qtccurrdirection == RECV) {
 	    if (strlen(qtc_recv_msgs[i]) > 0) {
-		strncpy(buff, qtc_recv_msgs[i], strlen(qtc_recv_msgs[i]) - 1);
-		buff[strlen(qtc_recv_msgs[i]) - 1] = '\0';
+		g_strlcpy(buff, qtc_recv_msgs[i], sizeof(buff));
 		mvwprintw(qtcwin, ++j, 36, "F%-2d: %s", (i + 1), buff);
 	    }
 	    if (i == 1) {
@@ -1560,8 +1551,7 @@ void show_help_msg(int msgidx) {
 	}
 	if (qtccurrdirection == SEND) {
 	    if (strlen(qtc_send_msgs[i]) > 0) {
-		strncpy(buff, qtc_send_msgs[i], strlen(qtc_send_msgs[i]) - 1);
-		buff[strlen(qtc_send_msgs[i]) - 1] = '\0';
+		g_strlcpy(buff, qtc_send_msgs[i], sizeof(buff));
 		mvwprintw(qtcwin, ++j, 36, "F%-2d: %s", (i + 1), buff);
 	    }
 	}
@@ -1590,7 +1580,7 @@ int parse_ry_line(char *line) {
 	nr_parsed_line = 1;
     }
 
-    strncpy(lline, line, strlen(line));
+    g_strlcpy(lline, line, sizeof(lline));
     tactivefield = activefield;
     if (nr_parsed_line == 0) {		// 1st line: SERIAL/NR
 	wtoken = strtok_r(lline, " ", &saveptr1);
@@ -1749,7 +1739,7 @@ void show_rtty_lines() {
     x = -1; j = 1;
     prevline = -1;
     curs_set(0);
-    while (x != 27) {
+    while (x != ESCAPE) {
 
 	while (x < 1) {
 
@@ -1820,7 +1810,7 @@ void show_rtty_lines() {
 		break;
 
 	    // Ctrl-R (^R)
-	    case 18:
+	    case CTRL_R:
 		for (j = 0; j < 12; j++) {
 		    qtc_ry_lines[j].content[0] = '\0';
 		    qtc_ry_lines[j].attr = 0;
@@ -1833,19 +1823,19 @@ void show_rtty_lines() {
 		break;
 
 	    // Ctrl-S (^S), start capture
-	    case 19:
+	    case CTRL_S:
 		qtc_ry_capture = 1;
 		mvwprintw(qtcwin, 2, 11, "CAPTURE ON ");
 		break;
 
 	    // Ctrl-E (^E), end capture
-	    case 5:
+	    case CTRL_E:
 		qtc_ry_capture = 0;
 		mvwprintw(qtcwin, 2, 11, "CAPTURE OFF");
 		break;
 
 	    // <Enter>, add to qtc
-	    case 10:
+	    case LINEFEED:
 		if (qtc_ry_lines[actline - 1].attr == 0) {
 		    parse_ry_line(qtc_ry_lines[actline - 1].content);
 		    qtc_ry_lines[actline - 1].attr = 1;
@@ -1856,7 +1846,7 @@ void show_rtty_lines() {
 		break;
 	}
 	refreshp();
-	if (x != 27) {
+	if (x != ESCAPE) {
 	    x = -1;
 	}
 	if (*qtccount > 0 && qtc_ry_copied == qtcreclist.count) {
@@ -1949,7 +1939,5 @@ void recalc_qtclist() {
 	    put_qtc();
 	}
     }
-    strncpy(prevqtccall, qtccallsign, strlen(qtccallsign));
-    prevqtccall[strlen(qtccallsign)] = '\0';
+    g_strlcpy(prevqtccall, qtccallsign, sizeof(prevqtccall));
 }
-
