@@ -22,7 +22,9 @@
 #ifndef READCALLS_H
 #define READCALLS_H
 
+int lookup_country_in_pfxnummult_array(int n);
 int readcalls(void);
+int log_read_n_score();
 int synclog(char *synclogfile);
 
 #endif /* READCALLS_H */
