@@ -17,10 +17,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-	/* ------------------------------------------------------------
-	 *
-	 *              Read country data  from disk file cty.dat
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *
+ *              Read country data  from disk file cty.dat
+ *--------------------------------------------------------------*/
 
 
 #include <stdio.h>
@@ -34,54 +34,13 @@
 #include "tlf.h"
 #include "tlf_curses.h"
 
-/** load cty database from filename */
-int load_ctydata(char *filename) {
-    FILE *fd;
-    char buf[181] = "";
-    char *loc;
 
-    if ((fd = fopen(filename, "r")) == NULL) 
-	return -1;
-
-    dxcc_init();
-    prefix_init();
-
-    // set default for empty country
-    dxcc_add("Not Specified        :    --:  --:  --:  -00.00:    00.00:     0.0:     :");
-
-    while (fgets(buf, sizeof(buf), fd) != NULL) {
-
-	g_strchomp(buf); 	/* drop CR and/or NL and */
-	if (*buf == '\0')	/* ignore empty lines */
-	    continue;
-
-	if (buf[0] != ' ') {	// data line
-
-	    dxcc_add(buf);
-
-	} else			// prefix line
-	{
-	    loc = strtok(buf, " ,;");
-	    while (loc != NULL) {
-
-		prefix_add (loc);
-
-		loc = strtok(NULL, " ,;");
-	    }
-	}
-    }
-    fclose(fd);
-    return 0;
-}
-
-
-int readctydata(void)
-{
+int readctydata(void) {
     gchar *filename;
- 
+
     if (load_ctydata("cty.dat") == -1) {
-	filename = g_strconcat(PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S, 
-		    "cty.dat", NULL);
+	filename = g_strconcat(PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S,
+			       "cty.dat", NULL);
 	if (load_ctydata(filename) == -1) {
 	    g_free(filename);
 	    mvprintw(4, 0, "Error opening cty.dat file.\n");
