@@ -174,27 +174,28 @@ void ry_addchar(char c) {
 
 /* ----------------------  display rtty ---------------------------------- */
 
-int show_rtty(void) {
+void show_rtty(void) {
 
     extern int miniterm;
     extern int commentfield;
     extern char comment[];
 
-    if (miniterm == 0)
-	return (-1);
+    if (!miniterm) {
+	return;
+    }
 
     attroff(A_STANDOUT);
     attron(modify_attr(COLOR_PAIR(C_HEADER)));
 
-    mvprintw(1, 0, "                                        ");
+    mvprintw(1, 0, spaces(40));
     mvprintw(1, 0, "%s", ry_term[0]);
-    mvprintw(2, 0, "                                        ");
+    mvprintw(2, 0, spaces(40));
     mvprintw(2, 0, "%s", ry_term[1]);
-    mvprintw(3, 0, "                                        ");
+    mvprintw(3, 0, spaces(40));
     mvprintw(3, 0, "%s", ry_term[2]);
-    mvprintw(4, 0, "                                        ");
+    mvprintw(4, 0, spaces(40));
     mvprintw(4, 0, "%s", ry_term[3]);
-    mvprintw(5, 0, "                                        ");
+    mvprintw(5, 0, spaces(40));
     mvprintw(5, 0, "%s", ry_term[4]);
     if (commentfield == 0) {
 	printcall();
@@ -204,7 +205,6 @@ int show_rtty(void) {
     refreshp();
     attron(A_STANDOUT);
 
-    return (0);
 }
 
 /* ---------------------  receive rtty ----------------------------------- */
