@@ -29,7 +29,7 @@
 int init_controller() ;
 void deinit_controller();
 int rx_rtty() ;
-int show_rtty(void);
+void show_rtty(void);
 
 #endif /* end of include guard: RTTY_H */
 
