@@ -24,6 +24,7 @@
  *--------------------------------------------------------------*/
 
 
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -54,8 +55,6 @@ int srch_index = 0;
 
 char qtcflags[6] = {' ', ' ', ' ', ' ', ' ', ' '};
 
-static const int xwin = 1;
-static const int ywin = 1;
 PANEL *search_panel;
 WINDOW *search_win;
 static int initialized = 0;
@@ -114,8 +113,7 @@ void drawSearchWin(void) {
 
     wattrset(search_win, COLOR_PAIR(C_LOG) | A_STANDOUT);
     for (i = 0; i < nr_bands; i++)
-	mvwprintw(search_win, i + 1, 1,
-		  "                                     ");
+	mvwprintw(search_win, i + 1, 1, spaces(37));
 
     mvwprintw(search_win, 1, 1, " 10");
     mvwprintw(search_win, 2, 1, " 15");
@@ -150,23 +148,72 @@ void displayCallInfo(dxcc_data *dx, int z, char *pxstr) {
     }
 }
 
+
+#define PARTIALS_ROWS   5
+#define PARTIALS_COLS   40      // including margins (1+1 columns)
+#define PARTIALS_Y0     1
+#define PARTIALS_X0     0
+
+//
+// return: true if display is full
+//
+static bool show_partial(int *row, int *col, char *call,
+			 GHashTable *callset,
+			 int *nr_suggested, char *suggested_call) {
+
+    const int len = strlen(call);
+    bool space = (*col > 1);         // whether to put leading space
+    int new_col = *col + (space ? 1 : 0) + len;
+    if (new_col >= PARTIALS_COLS) { // doesn't fit on this line
+	*row += 1;                  // start next one
+	*col = 1;
+	space = false;
+	new_col = *col + len;
+    }
+    if (*row >= PARTIALS_ROWS) {
+	return true;    // display full
+    }
+
+    if (!g_hash_table_add(callset, call)) {
+	return false;   // already shown
+    }
+
+    mvprintw(PARTIALS_Y0 + *row, PARTIALS_X0 + *col, "%s%s",
+	     (space ? " " : ""), call);
+
+    *col = new_col;
+
+    if (*nr_suggested == 0) {   // remember first partial call
+	strcpy(suggested_call, call);
+    }
+    *nr_suggested += 1;
+
+    return false;   // assume it's not full yet
+}
+
 int displayPartials(char *suggested_call) {
     extern int dupe;
 
-    int l, j, k;
+    int row, col, k;
     char *loc;
     char printres[14] = "";
     int suggested = 0;
 
-    l = 0;
-    j = 0;
+    const int hislen = strlen(hiscall);
+
+    if (hislen < 2) {
+	return 0;   // input too short
+    }
+
+    row = 0;
+    col = 1;        // 1 column left margin
 
     attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
 
-    for (k = 1; k <= 5; k++) {
-	mvprintw(k, 0, "%s",
-		 "                                        ");
+    for (k = 0; k < PARTIALS_ROWS; k++) {
+	mvprintw(PARTIALS_Y0 + k, 0, "%*s", PARTIALS_COLS, "");
     }
+
     attrset(COLOR_PAIR(C_DUPE));
     mvprintw(1, 1, "??");
     attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
@@ -182,75 +229,73 @@ int displayPartials(char *suggested_call) {
      * be aware of the problem of marking it dupe only for a complete
      * match.
      */
-    for (k = 0; k < srch_index; k++) {
-	if (strlen(hiscall) >= 2 && strlen(searchresult[k]) > 2) {
-	    if (strstr(searchresult[k], hiscall) != NULL) {
-		printres[0] = '\0';
-		strncat(printres, searchresult[k] + 29, 12);
+    if (dupe == ISDUPE) {
+	attrset(COLOR_PAIR(C_DUPE));
+    } else {
+	attron(modify_attr(COLOR_PAIR(C_BORDER) | A_STANDOUT));
+    }
 
-		/* cut string just at first space after call */
-		loc = strchr(printres, ' ');
-		if (loc)
-		    *loc = '\0';
+    GHashTable *callset = g_hash_table_new(g_str_hash, g_str_equal);
+    int full = 0;
 
-		if (dupe == ISDUPE) {
-		    attrset(COLOR_PAIR(C_DUPE));
-		} else {
-		    attron(modify_attr(COLOR_PAIR(C_BORDER) |
-				       A_STANDOUT));
-		}
-		mvprintw(xwin + l, ywin + j, "%s ", printres);
-		attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+    for (k = 0; k < srch_index && !full; k++) {
+	if (strlen(searchresult[k]) <= 2) {
+	    continue;   // too short (unlikely)
+	}
+	if (strstr(searchresult[k], hiscall) == NULL) {
+	    continue;   // not matching
+	}
 
-		attroff(A_BOLD);
+	printres[0] = '\0';
+	strncat(printres, searchresult[k] + 29, 12);
 
-		j += (strlen(printres) + 1);
+	/* cut string just at first space after call */
+	loc = strchr(printres, ' ');
+	if (loc)
+	    *loc = '\0';
 
-		if (j >= 30) {
-		    l++;
-		    j = 0;
+	full = show_partial(&row, &col, printres, callset,
+			    &suggested, suggested_call);
 
-		}
-		if (l > 4)
-		    break;
+    }
+
+    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+    attroff(A_BOLD);
+
+    /* and now check callmaster database */
+
+    attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
+
+    // make 2 runs: fist look for calls starting with
+    // then the ones containing 'hiscall'
+    for (int run = 1; run <= 2; run++) {
+	for (k = 0; k < callmaster->len && !full; k++) {
+
+	    char *mastercall = CALLMASTERARRAY(k);
+
+	    int match;
+	    if (run == 1) { // starts with
+		match = (strncmp(mastercall, hiscall, hislen) == 0);
+	    } else {        // contains
+		match = (strstr(mastercall, hiscall) != NULL);
 	    }
+
+	    if (!match) {
+		continue;   // not matching
+	    }
+
+	    full = show_partial(&row, &col, mastercall, callset,
+				&suggested, suggested_call);
+
 	}
     }
 
-    if (strcmp(hiscall, printres) != 0) {
+    g_hash_table_destroy(callset);
 
-	/* and now check callmaster database */
-	for (k = 0; k < callmaster->len; k++) {
-
-	    if (strstr(CALLMASTERARRAY(k), hiscall) != NULL) {
-
-		attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
-
-		mvprintw(xwin + l, ywin + j, "%s  ",
-			 CALLMASTERARRAY(k));
-
-		if (strlen(suggested_call) == 0) {
-		    strcpy(suggested_call, CALLMASTERARRAY(k));
-		    suggested++;
-		}
-
-		j += strlen(CALLMASTERARRAY(k)) + 1;
-
-		if (j >= 30) {
-		    l++;
-		    j = 0;
-
-		}
-		if (l > 4)
-		    break;
-
-	    }
-	}
-    }
     return suggested;
 }
 
-/* Display list of partials and handle USEPARTIAL auto-completion */
+/* Display list of partials and handle USEPARTIALS auto-completion */
 void handlePartials(void) {
     extern int use_part;
     extern int block_part;
@@ -261,25 +306,15 @@ void handlePartials(void) {
     /* print list of partials in upper left region */
     nr_suggested = displayPartials(suggested_call);
 
-    /* pick call from log if unique there */
-    if ((nr_suggested == 0) && (srch_index == 1)) {
-	gchar **list = g_strsplit(result[0] + 12, " ", 2);
-	if (list != NULL) {
-	    g_strlcpy(suggested_call, list[0], 13);
-	    g_strfreev(list);
-	}
-    }
-    nr_suggested += srch_index;
-
     /* If only one partial call found and USEPARTIALS set,
     * use that call for auto-completion. Can be blocked by
     * pressing tab in calledit() function
     */
-    if ((nr_suggested == 1) && (use_part == 1) && (block_part == 0)) {
-	if (strlen(suggested_call) > strlen(hiscall)) {
-	    strcpy(hiscall, suggested_call);
-	    beep();
-	}
+    if ((nr_suggested == 1) && use_part && !block_part
+	    && strlen(suggested_call) > strlen(hiscall)) {
+
+	strcpy(hiscall, suggested_call);
+	beep();
     }
 }
 
@@ -325,58 +360,89 @@ int bandstr2line(char *buffer) {
     return j;
 }
 
+//
+// return true if the qso was in the same mode as the current one
+//
+static bool is_current_mode(const char *qso) {
+    extern int trxmode;
+    extern int mixedmode;
+
+    if (mixedmode) {
+	return true;    // always true in mixed mode
+    }
+
+    if (qso[3] == 'S') {
+	return trxmode == SSBMODE;
+    }
+    if (qso[3] == 'D') {
+	return trxmode == DIGIMODE;
+    }
+    return trxmode == CWMODE;   // default
+}
+
 
 /* search complete Log for 'hiscall' as substring in callsign field and
  * copy found QSO to 'searchresults'. Extract relevant data to 'result'.
  * */
 void filterLog() {
-    extern int mixedmode;
-    extern int trxmode;
     extern char qsos[MAX_QSOS][LOGLINELEN + 1];
 
-    int qso_index = 0;
     char s_inputbuffer[LOGLINELEN + 1] = "";
 
     srch_index = 0;
 
-    while (strlen(qsos[qso_index]) > 4) {
+    for (int qso_index = 0; strlen(qsos[qso_index]) > 4; qso_index++) {
 
-	if (((qsos[qso_index][3] == 'C' && trxmode == CWMODE) ||
-		(qsos[qso_index][3] == 'S' && trxmode == SSBMODE) ||
-		(qsos[qso_index][3] == 'D' && trxmode == DIGIMODE)) ||
-		mixedmode == 0) {
-	    // ist letzterTest korrekt?
+	if (!is_current_mode(qsos[qso_index])) {
+	    continue;   // different mode
+	}
 
-	    g_strlcpy(s_inputbuffer, qsos[qso_index] + 29, 13); /* call */
-	    if (strstr(s_inputbuffer, hiscall) != 0) {
+	g_strlcpy(s_inputbuffer, qsos[qso_index] + 29, 13); /* call */
+	if (strstr(s_inputbuffer, hiscall) == 0) {
+	    continue;   // no match
+	}
 
-		g_strlcpy(searchresult[srch_index], qsos[qso_index], 81);
-		extractData(srch_index);
+	g_strlcpy(searchresult[srch_index], qsos[qso_index], 81);
+	extractData(srch_index);
 
-		if (srch_index++ > MAX_CALLS - 1)
-		    break;
-	    }
+	if (srch_index++ > MAX_CALLS - 1) {
+	    break;
 	}
-	qso_index++;
     }
 }
 
+//
+// check if station was worked in the current minitest period
+// it takes into account actual mode/band info
+//
+bool worked_in_current_minitest_period(int found) {
+
+    if (found < 0) {
+	return false;
+    }
+    if (!minitest) {
+	return true;    // minitest is off, so the answer is yes
+    }
+
+    long currtime = (long) mktime(time_ptr);
+    long period_start = (currtime / minitest) * minitest;
+    return worked[found].qsotime[trxmode][bandinx] >= period_start;
+}
+
 void displaySearchResults(void) {
     extern int dupe;
     extern int ignoredupe;
     extern int qso_once;
     extern int mixedmode;
     extern int ignoredupe;
-    extern int minitest;
     extern int bandinx;
     extern char band[NBANDS][4];
 
     int r_index;
     char s_inputbuffer[LOGLINELEN + 1] = "";
     char qtccall[15];	// temp str for qtc search
-    int found, display_dupe, mod;
+    bool display_dupe;
     int z, l, j;
-    time_t currtime;
     struct t_qtc_store_obj *qtc_temp_ptr;
 
 
@@ -396,28 +462,13 @@ void displaySearchResults(void) {
 		/* band matches */
 		if (ignoredupe == 0) { /* do we ignore dupes? */
 
-		    display_dupe = 1;
-		    if (minitest > 0) {
-			found = searchcallarray(hiscall);
-			if (found > -1) {
-			    currtime = mktime(time_ptr);
-			    mod = ((long)currtime) % minitest;	/* how many secods passed till last period */
-			    if (worked[found].qsotime[trxmode][bandinx] < (((long)currtime) - mod)) {
-				display_dupe = 0;
-			    }
-			}
-		    }
+		    int found = searchcallarray(hiscall);
+		    display_dupe = worked_in_current_minitest_period(found);
 
-		    if (display_dupe == 1) {
-			if ((mixedmode == 0) ||
-			    ((s_inputbuffer[3] == 'C') &&
-				    (trxmode == CWMODE)) ||
-			    ((s_inputbuffer[3] == 'S') &&
-				    (trxmode == SSBMODE))) {
-			    wattrset(search_win, COLOR_PAIR(C_DUPE));
-			    dupe = ISDUPE;
-			    beep();
-			}
+		    if (display_dupe && is_current_mode(s_inputbuffer)) {
+			wattrset(search_win, COLOR_PAIR(C_DUPE));
+			dupe = ISDUPE;
+			beep();
 		    }
 		}		// end ignoredupe
 	    }
@@ -667,7 +718,7 @@ void displayWorkedZonesCountries(int z) {
 }
 
 
-void searchlog(char *searchstring) {
+void searchlog() {
 
     extern int isdupe;		// LZ3NY auto-b4 patch
     extern int searchflg;
@@ -774,6 +825,8 @@ int load_callmaster(void) {
 	}
     }
 
+    GHashTable *callset = g_hash_table_new(g_str_hash, g_str_equal);
+
     while (fgets(s_inputbuffer, 85, cfp) != NULL) {
 
 	g_strstrip(s_inputbuffer);
@@ -783,18 +836,28 @@ int load_callmaster(void) {
 	    continue;
 	}
 
-	s_inputbuffer[12] = '\0';		/* terminate line length */
+	char *call = g_ascii_strup(s_inputbuffer, 11);
 
 	if (arrlss) {
 	    /* keep only NA stations */
-	    if (strchr("AKWVCN", s_inputbuffer[0]) == NULL) {
+	    if (strchr("AKWVCN", call[0]) == NULL) {
+		g_free(call);
 		continue;
 	    }
 	}
 
-	g_ptr_array_add(callmaster, g_strdup(s_inputbuffer));
+	if (g_hash_table_contains(callset, call)) { // already have this call
+	    g_free(call);
+	    continue;
+	}
+
+	g_hash_table_add(callset, call);
+
+	g_ptr_array_add(callmaster, call);
     }
 
+    g_hash_table_destroy(callset);
+
     fclose(cfp);
     return callmaster->len;
 }
@@ -815,7 +878,7 @@ void show_needed_sections(void) {
 	wattron(search_win, modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
 	for (j = 1; j < 7; j++)
-	    mvwprintw(search_win, j, 1, "                                     ");
+	    mvwprintw(search_win, j, 1, spaces(37));
 
 	for (vert = 1; vert < 7; vert++) {
 	    if (cnt >= get_mult_count())
@@ -859,7 +922,7 @@ void show_needed_sections(void) {
 }
 
 void OnLowerSearchPanel(int x, char *str) {
-    int y = 1 + (IsAllBand() ? 9 : 6);
+    int y = 1 + (IsAllBand() ? 10 : 6);
 
     wattrset(search_win, modify_attr(COLOR_PAIR(C_BORDER)));
     mvwprintw(search_win, y, x, str);
