@@ -21,6 +21,7 @@
 #ifndef SEARCHLOG_H
 #define SEARCHLOG_H
 
+#include <stdbool.h>
 #include <glib.h>
 
 #define CALLMASTER_SIZE 16000
@@ -33,7 +34,10 @@ extern char *callmaster_filename;
 
 int load_callmaster(void);
 
-void searchlog(char *searchstring);
+/* search 'hiscall' in the log */
+void searchlog(void);
+
+bool worked_in_current_minitest_period(int found);
 
 void InitSearchPanel(void);
 void ShowSearchPanel(void);
