@@ -33,6 +33,7 @@
 #include "callinput.h"
 #include "displayit.h"
 #include "globalvars.h"
+#include "keystroke_names.h"
 #include "lancode.h"
 #include "netkeyer.h"
 #include "tlf.h"
@@ -202,9 +203,9 @@ void ExpandMacro(void) {
     }
 
 
-    strncpy(rst_out, his_rst, 4);
-    rst_out[1] = short_number(rst_out[1]);
-    rst_out[2] = short_number(rst_out[2]);
+    rst_out[0] = his_rst[0];
+    rst_out[1] = short_number(his_rst[1]);
+    rst_out[2] = short_number(his_rst[2]);
     rst_out[3] = '\0';
 
     replace_all(buffer, BUFSIZE, "[", rst_out);   /* his RST */
@@ -247,7 +248,6 @@ void sendbuf(void) {
     extern int trxmode;
     extern int searchflg;
     extern char termbuf[];
-    extern char backgrnd_str[];
     extern int cwkeyer;
     extern int digikeyer;
     extern int simulator;
@@ -272,10 +272,7 @@ void sendbuf(void) {
 //              }
 	}
 
-	if (simulator == 0)
-	    strncat(printlinebuffer, termbuf, strlen(termbuf));
-	else
-	    strncat(printlinebuffer, termbuf, strlen(termbuf));
+	g_strlcpy(printlinebuffer, termbuf, sizeof(printlinebuffer));
 
 	if (searchflg == 0 && simulator == 0)
 	    strncat(printlinebuffer, backgrnd_str,
@@ -308,13 +305,13 @@ void sendbuf(void) {
 		int i = 0;
 		for (i = 0; i < strlen(buffer); i++)
 		    if (buffer[i] == '\n')
-			buffer[i] = 13;
+			buffer[i] = RETURN;
 		for (i = 0; i < strlen(buffer); i++)
 		    if (buffer[i] == 123)
 			buffer[i] = 20;	/* ctrl-t */
 		for (i = 0; i < strlen(buffer); i++)
 		    if (buffer[i] == 125)
-			buffer[i] = 18;	/* ctrl-r */
+			buffer[i] = CTRL_R;	/* ctrl-r */
 	    }
 	    keyer_append(buffer);
 	}
@@ -325,7 +322,7 @@ void sendbuf(void) {
 		int i = 0;
 		for (i = 0; i < strlen(buffer); i++)
 		    if (buffer[i] == '\n')
-			buffer[i] = 13;
+			buffer[i] = RETURN;
 	    }
 	    keyer_append(buffer);
 	}
