@@ -31,7 +31,7 @@
 #include "tlf.h"
 
 
-int setcontest(void) {
+void setcontest(void) {
 
     extern int focm;
     extern int wpx;
@@ -47,7 +47,6 @@ int setcontest(void) {
     extern int pacc_pa_flg;
     extern int stewperry_flg;
     extern int universal;
-    extern int other_flg;
     extern int exchange_serial;
     extern int wysiwyg_multi;
     extern int w_cty;
@@ -103,6 +102,9 @@ int setcontest(void) {
     sectn_mult = 0;
     noleadingzeros = 0;
 
+    w_cty = getctynr(wcall);
+    ve_cty = getctynr(vecall);
+
     if (strcmp(whichcontest, "wpx") == 0) {
 	wpx = 1;
 	contest = 1;
@@ -116,8 +118,6 @@ int setcontest(void) {
 	contest = 1;
 	showscore_flag = 1;
 	searchflg = 1;
-	w_cty = getctynr(wcall);
-	ve_cty = getctynr(vecall);
     }
 
     if (strcmp(whichcontest, "dxped") == 0) {
@@ -155,7 +155,6 @@ int setcontest(void) {
     }
     if (strcmp(whichcontest, "arrl_ss") == 0) {
 	arrlss = 1;
-	other_flg = 1;
 	two_point = 1;
 	qso_once = 1;
 	exchange_serial = 1;
@@ -184,8 +183,6 @@ int setcontest(void) {
 	showscore_flag = 1;
 	searchflg = 1;
 
-	ve_cty = getctynr(vecall);
-	w_cty = getctynr(wcall);
 	zl_cty = getctynr(zlcall);
 	ja_cty = getctynr(jacall);
 	py_cty = getctynr(pycall);
@@ -208,7 +205,6 @@ int setcontest(void) {
     }
 
     if (strcmp(whichcontest, "other") == 0) {
-	other_flg = 1;
 	one_point = 1;
 	recall_mult = 1;
 	wysiwyg_multi = 1;
@@ -228,8 +224,6 @@ int setcontest(void) {
 //      universal = 1;
 	showscore_flag = 1;
 	searchflg = 1;
-	w_cty = getctynr(wcall);
-	ve_cty = getctynr(vecall);
     }
 
     if (strcmp(whichcontest, "qso") == 0) {
@@ -241,6 +235,4 @@ int setcontest(void) {
 	showscore_flag = 1;
 	universal = 1;
     }
-
-    return (0);
 }
