@@ -31,12 +31,14 @@
  */
 
 
+#include <assert.h>
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
 
 #include "dxcc.h"
+#include "getwwv.h"
 #include "qrb.h"
 #include "showinfo.h"
 #include "tlf.h"
@@ -55,7 +57,6 @@ void showinfo(int x) {
     extern long timecorr;
     extern char itustr[];
     extern int mycountrynr;
-    extern char backgrnd_str[];
 
     int cury, curx;
     char pxstr[16];
@@ -83,7 +84,8 @@ void showinfo(int x) {
     strcpy(countrystr, dx->countryname);	/* country */
 
     if (strlen(cqzone) < 2) {
-	sprintf(zonestr, "%02d", dx->cq); 	/* cqzone */
+	if (dx->cq > MAX_ZONES) dx->cq = MAX_ZONES;
+	snprintf(zonestr, sizeof(zonestr), "%02d", dx->cq); 	/* cqzone */
 	strcpy(cqzone, zonestr);
     } else {
 	strncpy(zonestr, cqzone, 2);
@@ -124,22 +126,22 @@ void showinfo(int x) {
     getyx(stdscr, cury, curx);
     attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
-    mvprintw(LINES - 1, 0, backgrnd_str);
+    mvaddstr(LINES - 1, 0, backgrnd_str);
 
     if (contstr[0] != '-') {
 	mvprintw(LINES - 1, 0, " %s  %s", pxstr, countrystr);
 
-	mvprintw(LINES - 1, 26,
-		 " %s %s",
-		 contstr, zonestr);
+	mvprintw(LINES - 1, 26, " %s %s", contstr, zonestr);
 
 	if (x != 0 && x != mycountrynr && 0 == get_qrb(&range, &bearing)) {
 	    mvprintw(LINES - 1, 35, "%.0f km/%.0f deg ", range, bearing);
 	}
 
 	mvprintw(LINES - 1, LINELENGTH - 17, "   DX time: %s", timebuff);
+    } else {
+        wwv_show_footer();
     }
 
     attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
-    mvprintw(cury, curx, "");
+    move(cury, curx);
 }
