@@ -22,18 +22,20 @@
  *--------------------------------------------------------------*/
 
 
+#include <glib.h>
 #include <string.h>
 
 #include "dxcc.h"
 #include "focm.h"
 #include "changepars.h"
+#include "keystroke_names.h"
 #include "tlf.h"
 #include "tlf_curses.h"
 #include "ui_utils.h"
 #include "bands.h"
 
 
-int show_mults(void) {
+void show_mults(void) {
 
     extern int countries[MAX_DATALINES];
     extern int bandinx;
@@ -50,7 +52,7 @@ int show_mults(void) {
 
     if (focm == 1) {
 	foc_show_cty();
-	return 0;
+	return;
     }
 
     if (cqww == 1) {
@@ -63,7 +65,7 @@ int show_mults(void) {
 
 	while (ch != '\n' && ch != KEY_ENTER) {
 
-	    if (ch == 27)
+	    if (ch == ESCAPE)
 		break;
 
 	    zonecmp[0] = '\0';
@@ -85,8 +87,7 @@ int show_mults(void) {
 	    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 	    for (l = 1; l < 6; l++)
-		mvprintw(l, 0,
-			 "                                                                                ");
+		mvprintw(l, 0, backgrnd_str);
 
 	    i = 0;
 
@@ -105,10 +106,8 @@ int show_mults(void) {
 		    bandmask = inxes[bandinx];
 
 		    if ((countries[i] & bandmask) == 0) {
-			prefix[0] = '\0';
-			strncat(prefix, dxcc_by_index(i)->pfx, 3);
-
-			strncat(prefix, "     ", 4 - strlen(prefix));
+			strncpy(prefix, dxcc_by_index(i)->pfx, 3);
+			g_strlcat(prefix, "     ", sizeof(prefix));
 
 			attron(modify_attr(COLOR_PAIR(C_INPUT)));
 
@@ -139,11 +138,9 @@ int show_mults(void) {
 
 	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 	for (l = 1; l < 6; l++)
-	    mvprintw(l, 0,
-		     "                                                                                ");
+	    mvprintw(l, 0, backgrnd_str);
     } else
 
 	multiplierinfo();
 
-    return (0);
 }
