@@ -41,6 +41,7 @@
 #include "bandmap.h"
 #include "clear_display.h"
 #include "get_time.h"
+#include "getwwv.h"
 #include "globalvars.h"		// Includes glib.h and tlf.h
 #include "ignore_unused.h"
 #include "lancode.h"
@@ -50,8 +51,6 @@
 #include "ui_utils.h"
 #include "err_utils.h"
 
-extern char backgrnd_str[];
-
 struct tln_logline {
     struct tln_logline *next;
     struct tln_logline *prev;
@@ -94,7 +93,6 @@ char tln_input_buffer[2 * BUFFERSIZE];
 void setup_splitlayout();
 
 void addlog(char *s) {
-    extern char lastwwv[];
     extern char spot_ptr[MAX_SPOTS][82];
     extern char lastmsg[];
     extern int nr_of_spots;
@@ -144,8 +142,7 @@ void addlog(char *s) {
     // \todo drop it later tb mar11
     bm_add(s);
 
-    if ((strncmp(s, "WWV", 3) == 0) || strncmp(s, "WCY", 3) == 0)
-	strncpy(lastwwv, s, 82);
+    wwv_add(s);
 
     if (tln_loglines >= maxtln_loglines) {
 	temp = loghead;
@@ -547,10 +544,9 @@ void sanitize(char *s) {
 	if (*s == '\007')
 	    beep();
 	else if (*s == '\015');
-	else if (*s < 0)
-	    *t++ = *s - 128;
-	else
-	    *t++ = *s;
+	else {
+	    *t++ = *s & 0x7f;
+        }
     }
     *t = '\0';
 }
@@ -692,10 +688,8 @@ void addtext(char *s) {
 			spotline[m] -= 32;
 		}
 
-		strcat(spotline,
-		       "                                           ");
+		strcat(spotline, spaces(43));
 		get_time();
-//                                              strftime(spottime, 80, "%H%MZ", time_ptr);      ### bug fix
 		strftime(spottime, sizeof(spottime), "%H%MZ", time_ptr);
 		strcpy(spotline + 70, spottime);
 		spotline[75] = '\0';
