@@ -23,6 +23,7 @@
 
 
 #include "clear_display.h"
+#include "err_utils.h"
 #include "netkeyer.h"
 #include "tlf.h"
 #include "tlf_curses.h"
@@ -42,7 +43,7 @@ int stoptx(void) {
 
 	    if (netkeyer(K_ABORT, NULL) < 0) {
 
-		mvprintw(24, 0, "keyer not active; switching to SSB");
+		TLF_LOG_WARN("keyer not active; switching to SSB");
 		trxmode = SSBMODE;
 		clear_display();
 
