@@ -49,8 +49,13 @@
 
 #define SEARCHWINDOW 1  /* searchflg on */
 
-#define CQ 1			/* cqmode   on */
-#define S_P 0			/* S&P mode  on  */
+typedef enum {
+    CQ,         // Run
+    S_P,        // Search and Pounce
+    AUTO_CQ,    // temporary, used in autocq.c
+    KEYBOARD,   // temporary, used in keyer.c
+    NONE        // used in trx_memory to signal empty memory
+} cqmode_t;
 
 #define SEND_DE 1		/* de_mode on */
 #define CONTEST 1		/* contest mode on */
@@ -64,6 +69,7 @@
 #define SSBMODE 1
 #define DIGIMODE 2
 
+#define  BAND60 512
 #define  BAND30 256
 #define  BAND17 128
 #define  BAND12 64
@@ -79,6 +85,7 @@
 enum {
     BANDINDEX_160 = 0,
     BANDINDEX_80,
+    BANDINDEX_60,
     BANDINDEX_40,
     BANDINDEX_30,
     BANDINDEX_20,
@@ -115,19 +122,18 @@ enum {
 #define ITU_ZONES 90
 #define MAX_ZONES (ITU_ZONES + 1) /* size of zones array */
 
-#define EDITOR_JOE 0
-#define EDITOR_VI 1
-#define EDITOR_E3 2
-#define EDITOR_MC 3
-
 #define UNIQUECALL_ALL      1
 #define UNIQUECALL_BAND     2
 
+#define EXCLUDE_NONE 0
+#define EXCLUDE_CONTINENT 1
+#define EXCLUDE_COUNTRY 2
+
 #define LOGLINELEN (88)		/* Length of logline in logfile
 				   (including linefeed) */
 #define MINITEST_DEFAULT_PERIOD 600
-				/* ignore dupe state when MINITEST is set
-				 * and last QSO was not in actual period */
+/* ignore dupe state when MINITEST is set
+ * and last QSO was not in actual period */
 
 /* special message numbers */
 enum {
@@ -153,18 +159,20 @@ struct worked_t {
  * all information about worked multis */
 struct mults_t {
     char name[12];		/**< Multiplier */
-    int band;			/**< bitmap with abnds the multi was worked */
+    int band;			/**< bitmap with bands the multi was worked */
 };
 
 
 #define MAXPFXNUMMULT 30
 typedef struct {
     int countrynr;
-    int qsos[10];
+    int qsos[NBANDS];
 } t_pfxnummulti;
 
 
 void refreshp();
 
+extern const char *backgrnd_str;
+
 #endif /* TLF_H */
 
