@@ -22,9 +22,11 @@
 
 #include <pthread.h>
 #include <unistd.h>
+#include <glib.h>
 
 #include "clear_display.h"
 #include "clusterinfo.h"
+#include "keystroke_names.h"
 #include "stoptx.h"
 #include "tlf_panel.h"
 #include "startmsg.h"
@@ -166,11 +168,11 @@ static int onechar(void) {
 
     x = getch();
 
-    /* Replace Ctl-H and Backspace with KEY_BACKSPACE */
-    if (x == 8 || x == 127)
+    /* Replace Ctl-H (Backspace) and Delete with KEY_BACKSPACE */
+    if (x == CTRL_H || x == DELETE)
 	x = KEY_BACKSPACE;
 
-    if (x == 27) {
+    if (x == ESCAPE) {
 	nodelay(stdscr, TRUE);
 
 	x = getch();
@@ -179,7 +181,7 @@ static int onechar(void) {
 	if (x == ERR) {
 	    stoptx();
 
-	    return x = 27;
+	    return x = ESCAPE;
 
 	} else if (x != 91) {
 
@@ -338,3 +340,22 @@ void resize_layout(void) {
     clusterinfo();
     refresh_splitlayout();
 }
+
+#define MAX_SPACES  1000
+
+static char *spaces_buffer = NULL;
+
+const char *spaces(int n) {
+
+    if (spaces_buffer == NULL) {
+	spaces_buffer = g_strnfill(MAX_SPACES, ' ');
+    }
+
+    if (n < 0) {
+	n = 0;
+    } else if (n > MAX_SPACES) {
+	n = MAX_SPACES;
+    }
+
+    return spaces_buffer + (MAX_SPACES - n);
+}
