@@ -30,9 +30,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include <unistd.h>
 
 #include "getsummary.h"
+#include "log_utils.h"
 #include "tlf_curses.h"
 #include "ui_utils.h"
 #include "cabrillo_utils.h"
@@ -42,20 +44,10 @@ extern char call[];
 /* conversion table between tag name in format file and internal tag */
 extern struct tag_conv tag_tbl[];
 
-int is_comment(char *buffer);
 struct qso_t *get_next_record(FILE *fp);
 struct qso_t *get_next_qtc_record(FILE *fp, int qtcdirection);
 void free_qso(struct qso_t *ptr);
 
-/** check if logline is only a comment */
-int is_comment(char *buffer) {
-
-    if (buffer[0] != ';' && strlen(buffer) > 60) /** \todo better check */
-	return 0;
-    else
-	return 1;
-}
-
 /** get next qso record from log
  *
  * Read next line from logfile until it is no comment.
@@ -74,7 +66,7 @@ struct qso_t *get_next_record(FILE *fp) {
 
     while ((fgets(buffer, sizeof(buffer), fp)) != NULL) {
 
-	if (!is_comment(buffer)) {
+	if (!log_is_comment(buffer)) {
 
 	    ptr = g_malloc0(sizeof(struct qso_t));
 
@@ -615,7 +607,7 @@ int write_cabrillo(void) {
     /* ask for exchange and header information */
     ask(buffer,
 	"Your exchange (e.g. State, province, age etc... (# if serial number)): ");
-    strncpy(exchange, buffer, 10);
+    g_strlcpy(exchange, buffer, 11);
     getsummary(fp2);
 
     info("Writing cabrillo file");
@@ -688,6 +680,34 @@ int write_cabrillo(void) {
 }
 
 
+/* write ADIF header to open file */
+void write_adif_header(FILE* fp) {
+    extern char whichcontest[];
+
+    time_t now = time(0);
+    struct tm *time_ptr = gmtime(&now);
+    char timebuf[100];
+
+    fputs
+    ("################################################################################\n",
+     fp);
+    fputs ("#                     ADIF v3.10 data file exported by TLF\n", fp);
+    fputs ("#              according to specifications on http://www.adif.org\n", fp);
+    fputs
+    ("################################################################################\n",
+     fp);
+
+    strftime(timebuf, sizeof(timebuf), "%d-%b-%y at %H:%Mz", time_ptr);
+    fprintf(fp, "Created %s for %s\n", timebuf, call);
+
+    /* Write contest name */
+    fprintf(fp, "Contest Name: %s\n", whichcontest);
+    fputs("<adif_ver:4>3.10\n", fp);
+    fputs("<programid:3>TLF\n", fp);
+    fprintf(fp, "<programversion:%ld>%s\n", strlen(VERSION), VERSION);
+    fputs("<eoh>\n", fp);
+}
+
 
 /*
     The ADIF function has been written according ADIF v1.00 specifications
@@ -741,26 +761,12 @@ int write_adif(void) {
     if ((strlen(standardexchange) == 0) && (exchange_serial != 1)) {
 	ask(buffer,
 	    "Your exchange (e.g. State, province, age etc... (# if serial number)): ");
-	strncpy(standardexchange, buffer, 10);
+	g_strlcpy(standardexchange, buffer, 11);
     }
 
     info("Writing ADIF file");
 
-    /* write header */
-    fputs
-    ("################################################################################\n",
-     fp2);
-    fputs
-    ("#                     ADIF v1.00 data file exported by TLF\n",
-     fp2);
-    fputs
-    ("#              according to specifications on http://www.adif.org\n",
-     fp2);
-    fputs("#\n", fp2);
-    fputs
-    ("################################################################################\n",
-     fp2);
-    fputs("<adif_ver:4>1.00\n<eoh>\n", fp2);
+    write_adif_header(fp2);
 
     while (fgets(buf, sizeof(buf), fp1)) {
 
