@@ -19,6 +19,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 #include "../src/globalvars.h"
@@ -39,7 +40,7 @@ int use_rxvt = 0;
 int use_xterm = 0;
 
 int debugflag = 0;
-int editor = EDITOR_JOE;
+char *editor_name = NULL;
 char rttyoutput[120];
 int tune_val = 0;
 int use_bandoutput = 0;
@@ -65,7 +66,6 @@ int pfxmult = 0;
 int pfxmultab = 0;
 int exc_cont = 0;
 int manise80;
-int other_flg;
 int one_point = 0;
 int two_point = 0;
 int three_point = 0;
@@ -79,13 +79,13 @@ int my_country_points = -1;
 int my_cont_points = -1;
 int dx_cont_points = -1;
 char countrylist[255][6];
-int countrylist_only = 0;
+bool countrylist_only = false;
 int countrylist_points = -1;
 char continent_multiplier_list[7][3]; // SA, NA, EU, AF, AS and OC
 int continentlist_points = -1;
-int continentlist_only = 0;
-int exclude_multilist_type = 0;
-int mult_side = 0;
+bool continentlist_only = false;
+int exclude_multilist_type = EXCLUDE_NONE;
+bool mult_side = false;
 /* end LZ3NY mods */
 
 int portable_x2 = 0;
@@ -146,7 +146,7 @@ int cluster = NOCLUSTER;	/* 0 = OFF, 1 = FOLLOW, 2  = spots  3 = all */
 int clusterlog = 0;		/* clusterlog on/off */
 int searchflg = 0;		/* 1  = display search  window */
 int show_time = 0;
-int cqmode = CQ;		/* 1  = CQ  0 = S&P  */
+cqmode_t cqmode = CQ;
 int demode = 0;			/* 1 =  send DE  before s&p call  */
 int contest = 0;		/* 0 =  General,  1  = contest */
 int announcefilter = FILTER_ANN; /*  filter cluster  announcements */
@@ -279,7 +279,6 @@ int commentfield = 0;		/* 1 if we are in comment/excahnge input */
 /*-------------------------------------packet-------------------------------*/
 char spot_ptr[MAX_SPOTS][82];		/* Array of cluster spot lines */
 int nr_of_spots;			/* Anzahl Lines in spot_ptr array */
-char lastwwv[120] = "";
 int packetinterface = 0;
 int fdSertnc = 0;
 int fdFIFO = 0;
@@ -367,14 +366,14 @@ int logfrequency = 0;
 int rit;
 int trx_control = 0;
 int showfreq = 0;
-freq_t bandfrequency[9] = {
-    1830000.0, 3525000.0, 7010000.0, 10105000.0, 14025000.0, 18070000.0, 21025000.0, 24900000.0,
+freq_t bandfrequency[10] = {
+    1830000.0, 3525000.0, 5352000.0, 7010000.0, 10105000.0, 14025000.0, 18070000.0, 21025000.0, 24900000.0,
     28025000.0
 };
 
 char headerline[81] =
     "   1=CQ  2=DE  3=RST 4=73  5=HIS  6=MY  7=B4   8=AGN  9=?  \n";
-char backgrnd_str[81] =
+const char *backgrnd_str =
     "                                                                                ";
 
 char logline_edit[5][LOGLINELEN + 1];
@@ -391,8 +390,6 @@ double QTH_Long = -7.;
 double DEST_Lat = 51.;
 double DEST_Long = 1.;
 
-double r = 50;
-int m = 1;
 char hiscountry[40];
 
 int this_second;
@@ -405,8 +402,8 @@ char itustr[3];
 int nopacket = 0;		/* set if tlf is called with '-n' */
 int no_trx_control = 0;		/* set if tlf is called with '-r' */
 
-int bandweight_points[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1};
-int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1};
+int bandweight_points[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
+int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
 
 struct mults_t multis[MAX_MULTS]; /**< worked multis */
 int nr_multis = 0;      /**< number of multis in multis[] */
